@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 MongoDB, Inc.
+ * Copyright 2017-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,36 +14,14 @@
  * limitations under the License.
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <php.h>
 
-#include "phongo_compat.h"
 #include "php_phongo.h"
+#include "MinKeyInterface_arginfo.h"
 
 zend_class_entry* php_phongo_minkey_interface_ce;
 
-/* {{{ MongoDB\BSON\MinKeyInterface function entries */
-static zend_function_entry php_phongo_minkey_interface_me[] = {
-	PHP_FE_END
-};
-/* }}} */
-
-void php_phongo_minkey_interface_init_ce(INIT_FUNC_ARGS) /* {{{ */
+void php_phongo_minkey_interface_init_ce(INIT_FUNC_ARGS)
 {
-	zend_class_entry ce;
-
-	INIT_NS_CLASS_ENTRY(ce, "MongoDB\\BSON", "MinKeyInterface", php_phongo_minkey_interface_me);
-	php_phongo_minkey_interface_ce = zend_register_internal_interface(&ce TSRMLS_CC);
-} /* }}} */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
+	php_phongo_minkey_interface_ce = register_class_MongoDB_BSON_MinKeyInterface();
+}
