@@ -365,13 +365,13 @@ static zend_object* php_phongo_cursor_create_object(zend_class_entry* class_type
 	return &intern->std;
 }
 
-static HashTable* php_phongo_cursor_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_cursor_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_cursor_t* intern;
 	zval                 retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern   = Z_OBJ_CURSOR(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_CURSOR(object);
 
 	array_init_size(&retval, 10);
 
@@ -440,7 +440,6 @@ void php_phongo_cursor_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_cursor_ce                = register_class_MongoDB_Driver_Cursor(zend_ce_iterator, php_phongo_cursor_interface_ce);
 	php_phongo_cursor_ce->create_object = php_phongo_cursor_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_cursor_ce);
 
 	memcpy(&php_phongo_handler_cursor, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_cursor.get_debug_info = php_phongo_cursor_get_debug_info;
