@@ -198,7 +198,7 @@ static zend_object* php_phongo_commandstartedevent_create_object(zend_class_entr
 	return &intern->std;
 }
 
-static HashTable* php_phongo_commandstartedevent_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_commandstartedevent_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_commandstartedevent_t* intern;
 	zval                              retval = ZVAL_STATIC_INIT;
@@ -207,7 +207,7 @@ static HashTable* php_phongo_commandstartedevent_get_debug_info(phongo_compat_ob
 
 	PHONGO_BSON_INIT_STATE(command_state);
 
-	intern   = Z_OBJ_COMMANDSTARTEDEVENT(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_COMMANDSTARTEDEVENT(object);
 	*is_temp = 1;
 	array_init_size(&retval, 10);
 
@@ -264,7 +264,6 @@ void php_phongo_commandstartedevent_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_commandstartedevent_ce                = register_class_MongoDB_Driver_Monitoring_CommandStartedEvent();
 	php_phongo_commandstartedevent_ce->create_object = php_phongo_commandstartedevent_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_commandstartedevent_ce);
 
 	memcpy(&php_phongo_handler_commandstartedevent, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_commandstartedevent.get_debug_info = php_phongo_commandstartedevent_get_debug_info;
