@@ -109,7 +109,7 @@ static zend_object* php_phongo_serverheartbeatsucceededevent_create_object(zend_
 	return &intern->std;
 }
 
-static HashTable* php_phongo_serverheartbeatsucceededevent_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_serverheartbeatsucceededevent_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_serverheartbeatsucceededevent_t* intern;
 	zval                                        retval = ZVAL_STATIC_INIT;
@@ -117,7 +117,7 @@ static HashTable* php_phongo_serverheartbeatsucceededevent_get_debug_info(phongo
 
 	PHONGO_BSON_INIT_STATE(reply_state);
 
-	intern   = Z_OBJ_SERVERHEARTBEATSUCCEEDEDEVENT(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_SERVERHEARTBEATSUCCEEDEDEVENT(object);
 	*is_temp = 1;
 	array_init_size(&retval, 4);
 
@@ -141,7 +141,6 @@ void php_phongo_serverheartbeatsucceededevent_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_serverheartbeatsucceededevent_ce                = register_class_MongoDB_Driver_Monitoring_ServerHeartbeatSucceededEvent();
 	php_phongo_serverheartbeatsucceededevent_ce->create_object = php_phongo_serverheartbeatsucceededevent_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_serverheartbeatsucceededevent_ce);
 
 	memcpy(&php_phongo_handler_serverheartbeatsucceededevent, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_serverheartbeatsucceededevent.get_debug_info = php_phongo_serverheartbeatsucceededevent_get_debug_info;
