@@ -225,7 +225,7 @@ static PHP_METHOD(MongoDB_Driver_ReadPreference, __construct)
 			return;
 		}
 	} else {
-		phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT, "Expected mode to be integer or string, %s given", PHONGO_ZVAL_CLASS_OR_TYPE_NAME_P(mode));
+		phongo_throw_exception(PHONGO_ERROR_INVALID_ARGUMENT, "Expected mode to be integer or string, %s given", zend_zval_type_name(mode));
 		return;
 	}
 
@@ -425,7 +425,7 @@ static PHP_METHOD(MongoDB_Driver_ReadPreference, getTagSets)
 	}
 }
 
-static HashTable* php_phongo_readpreference_get_properties_hash(phongo_compat_object_handler_type* object, bool is_temp)
+static HashTable* php_phongo_readpreference_get_properties_hash(zend_object* object, bool is_temp)
 {
 	php_phongo_readpreference_t* intern;
 	HashTable*                   props;
@@ -434,7 +434,7 @@ static HashTable* php_phongo_readpreference_get_properties_hash(phongo_compat_ob
 	const bson_t*                hedge;
 	mongoc_read_mode_t           mode;
 
-	intern = Z_OBJ_READPREFERENCE(PHONGO_COMPAT_GET_OBJ(object));
+	intern = Z_OBJ_READPREFERENCE(object);
 
 	PHONGO_GET_PROPERTY_HASH_INIT_PROPS(is_temp, intern, props, 4);
 
@@ -501,7 +501,7 @@ static PHP_METHOD(MongoDB_Driver_ReadPreference, bsonSerialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
 
-	ZVAL_ARR(return_value, php_phongo_readpreference_get_properties_hash(PHONGO_COMPAT_OBJ_P(getThis()), true));
+	ZVAL_ARR(return_value, php_phongo_readpreference_get_properties_hash(Z_OBJ_P(getThis()), true));
 	convert_to_object(return_value);
 }
 
@@ -614,7 +614,7 @@ static PHP_METHOD(MongoDB_Driver_ReadPreference, __serialize)
 {
 	PHONGO_PARSE_PARAMETERS_NONE();
 
-	RETURN_ARR(php_phongo_readpreference_get_properties_hash(PHONGO_COMPAT_OBJ_P(getThis()), true));
+	RETURN_ARR(php_phongo_readpreference_get_properties_hash(Z_OBJ_P(getThis()), true));
 }
 
 static PHP_METHOD(MongoDB_Driver_ReadPreference, __unserialize)
@@ -659,13 +659,13 @@ static zend_object* php_phongo_readpreference_create_object(zend_class_entry* cl
 	return &intern->std;
 }
 
-static HashTable* php_phongo_readpreference_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_readpreference_get_debug_info(zend_object* object, int* is_temp)
 {
 	*is_temp = 1;
 	return php_phongo_readpreference_get_properties_hash(object, true);
 }
 
-static HashTable* php_phongo_readpreference_get_properties(phongo_compat_object_handler_type* object)
+static HashTable* php_phongo_readpreference_get_properties(zend_object* object)
 {
 	return php_phongo_readpreference_get_properties_hash(object, false);
 }
