@@ -110,13 +110,13 @@ static zend_object* php_phongo_writeerror_create_object(zend_class_entry* class_
 	return &intern->std;
 }
 
-static HashTable* php_phongo_writeerror_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_writeerror_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_writeerror_t* intern;
 	zval                     retval = ZVAL_STATIC_INIT;
 
 	*is_temp = 1;
-	intern   = Z_OBJ_WRITEERROR(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_WRITEERROR(object);
 
 	array_init_size(&retval, 3);
 	ADD_ASSOC_STRING(&retval, "message", intern->message);
@@ -136,7 +136,6 @@ void php_phongo_writeerror_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_writeerror_ce                = register_class_MongoDB_Driver_WriteError();
 	php_phongo_writeerror_ce->create_object = php_phongo_writeerror_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_writeerror_ce);
 
 	memcpy(&php_phongo_handler_writeerror, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_writeerror.get_debug_info = php_phongo_writeerror_get_debug_info;
