@@ -356,13 +356,13 @@ static zend_object* php_phongo_writeresult_create_object(zend_class_entry* class
 	return &intern->std;
 }
 
-static HashTable* php_phongo_writeresult_get_debug_info(phongo_compat_object_handler_type* object, int* is_temp)
+static HashTable* php_phongo_writeresult_get_debug_info(zend_object* object, int* is_temp)
 {
 	php_phongo_writeresult_t* intern;
 	zval                      retval = ZVAL_STATIC_INIT;
 	bson_iter_t               iter;
 
-	intern   = Z_OBJ_WRITERESULT(PHONGO_COMPAT_GET_OBJ(object));
+	intern   = Z_OBJ_WRITERESULT(object);
 	*is_temp = 1;
 	array_init_size(&retval, 10);
 
@@ -437,7 +437,6 @@ void php_phongo_writeresult_init_ce(INIT_FUNC_ARGS)
 {
 	php_phongo_writeresult_ce                = register_class_MongoDB_Driver_WriteResult();
 	php_phongo_writeresult_ce->create_object = php_phongo_writeresult_create_object;
-	PHONGO_CE_DISABLE_SERIALIZATION(php_phongo_writeresult_ce);
 
 	memcpy(&php_phongo_handler_writeresult, phongo_get_std_object_handlers(), sizeof(zend_object_handlers));
 	php_phongo_handler_writeresult.get_debug_info = php_phongo_writeresult_get_debug_info;
