@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,10 +18,13 @@
 #include <limits.h>
 #include <stdarg.h>
 
-#include "bson/bson-compat.h"
-#include "bson/bson-string.h"
-#include "bson/bson-memory.h"
-#include "bson/bson-utf8.h"
+#include <bson/bson-compat.h>
+#include <bson/bson-config.h>
+#include <common-cmp-private.h>
+#include <common-string-private.h>
+#include <common-bits-private.h>
+#include <bson/bson-memory.h>
+#include <bson/bson-utf8.h>
 
 #ifdef BSON_HAVE_STRINGS_H
 #include <strings.h>
@@ -29,272 +32,114 @@
 #include <string.h>
 #endif
 
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_new --
- *
- *       Create a new bson_string_t.
- *
- *       bson_string_t is a power-of-2 allocation growing string. Every
- *       time data is appended the next power of two size is chosen for
- *       the allocation. Pretty standard stuff.
- *
- *       It is UTF-8 aware through the use of bson_string_append_unichar().
- *       The proper UTF-8 character sequence will be used.
- *
- * Parameters:
- *       @str: a string to copy or NULL.
- *
- * Returns:
- *       A newly allocated bson_string_t that should be freed with
- *       bson_string_free().
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
 
 bson_string_t *
 bson_string_new (const char *str) /* IN */
 {
-   bson_string_t *ret;
-
-   ret = bson_malloc0 (sizeof *ret);
-   ret->len = str ? (int) strlen (str) : 0;
-   ret->alloc = ret->len + 1;
-
-   if (!bson_is_power_of_two (ret->alloc)) {
-      ret->alloc = (uint32_t) bson_next_power_of_two ((size_t) ret->alloc);
-   }
-
-   BSON_ASSERT (ret->alloc >= 1);
-
-   ret->str = bson_malloc (ret->alloc);
-
-   if (str) {
-      memcpy (ret->str, str, ret->len);
-   }
-   ret->str[ret->len] = '\0';
-
-   ret->str[ret->len] = '\0';
-
-   return ret;
+   /* Compatibility wrapper; deprecated.
+    * New mcommon_string behavior is to use power of two rounding for resize but not for initial allocation unless
+    * extra capacity is explicitly requested. This emulates the old behavior, padding the allocation of all new strings.
+    */
+   size_t len = str ? strlen (str) : 0;
+   BSON_ASSERT (mcommon_in_range_unsigned (uint32_t, len) && (uint32_t) len < UINT32_MAX);
+   uint32_t alloc = mcommon_next_power_of_two_u32 ((uint32_t) len + 1);
+   return (bson_string_t *) mcommon_string_new_with_capacity (str ? str : "", (uint32_t) len, alloc - 1);
 }
 
 char *
 bson_string_free (bson_string_t *string, /* IN */
                   bool free_segment)     /* IN */
 {
-   char *ret = NULL;
-
-   BSON_ASSERT (string);
-
-   if (!free_segment) {
-      ret = string->str;
+   // Compatibility wrapper; deprecated.
+   if (free_segment) {
+      mcommon_string_destroy ((mcommon_string_t *) string);
+      return NULL;
    } else {
-      bson_free (string->str);
+      return mcommon_string_destroy_with_steal ((mcommon_string_t *) string);
    }
-
-   bson_free (string);
-
-   return ret;
 }
 
-
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_append --
- *
- *       Append the UTF-8 string @str to @string.
- *
- * Returns:
- *       None.
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
-
 void
 bson_string_append (bson_string_t *string, /* IN */
                     const char *str)       /* IN */
 {
-   uint32_t len;
+   // Compatibility wrapper; deprecated.
+   BSON_ASSERT_PARAM (string);
+   BSON_ASSERT_PARAM (str);
 
-   BSON_ASSERT (string);
-   BSON_ASSERT (str);
-
-   len = (uint32_t) strlen (str);
-
-   if ((string->alloc - string->len - 1) < len) {
-      string->alloc += len;
-      if (!bson_is_power_of_two (string->alloc)) {
-         string->alloc =
-            (uint32_t) bson_next_power_of_two ((size_t) string->alloc);
-      }
-      string->str = bson_realloc (string->str, string->alloc);
-   }
-
-   memcpy (string->str + string->len, str, len);
-   string->len += len;
-   string->str[string->len] = '\0';
+   mcommon_string_append_t append;
+   mcommon_string_set_append ((mcommon_string_t *) string, &append);
+   (void) mcommon_string_append (&append, str);
 }
 
-
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_append_c --
- *
- *       Append the ASCII character @c to @string.
- *
- *       Do not use this if you are working with UTF-8 sequences,
- *       use bson_string_append_unichar().
- *
- * Returns:
- *       None.
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
-
-void
-bson_string_append_c (bson_string_t *string, /* IN */
-                      char c)                /* IN */
-{
-   char cc[2];
-
-   BSON_ASSERT (string);
-
-   if (BSON_UNLIKELY (string->alloc == (string->len + 1))) {
-      cc[0] = c;
-      cc[1] = '\0';
-      bson_string_append (string, cc);
-      return;
-   }
-
-   string->str[string->len++] = c;
-   string->str[string->len] = '\0';
-}
-
-
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_append_unichar --
- *
- *       Append the bson_unichar_t @unichar to the string @string.
- *
- * Returns:
- *       None.
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
-
 void
 bson_string_append_unichar (bson_string_t *string,  /* IN */
                             bson_unichar_t unichar) /* IN */
 {
-   uint32_t len;
-   char str[8];
+   // Compatibility wrapper; deprecated.
+   BSON_ASSERT_PARAM (string);
 
-   BSON_ASSERT (string);
-   BSON_ASSERT (unichar);
-
-   bson_utf8_from_unichar (unichar, str, &len);
-
-   if (len <= 6) {
-      str[len] = '\0';
-      bson_string_append (string, str);
-   }
+   mcommon_string_append_t append;
+   mcommon_string_set_append ((mcommon_string_t *) string, &append);
+   (void) mcommon_string_append_unichar (&append, unichar);
 }
 
+void
+bson_string_append_c (bson_string_t *string, /* IN */
+                      char c)                /* IN */
+{
+   // Compatibility wrapper; deprecated.
+   BSON_ASSERT_PARAM (string);
 
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_append_printf --
- *
- *       Format a string according to @format and append it to @string.
- *
- * Returns:
- *       None.
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
+   mcommon_string_append_t append;
+   mcommon_string_set_append ((mcommon_string_t *) string, &append);
+   (void) mcommon_string_append_bytes (&append, &c, 1);
+}
 
 void
 bson_string_append_printf (bson_string_t *string, const char *format, ...)
 {
+   // Compatibility wrapper; deprecated.
+   BSON_ASSERT_PARAM (string);
+   BSON_ASSERT_PARAM (format);
+
    va_list args;
-   char *ret;
-
-   BSON_ASSERT (string);
-   BSON_ASSERT (format);
-
+   mcommon_string_append_t append;
+   mcommon_string_set_append ((mcommon_string_t *) string, &append);
    va_start (args, format);
-   ret = bson_strdupv_printf (format, args);
+   (void) mcommon_string_append_vprintf (&append, format, args);
    va_end (args);
-   bson_string_append (string, ret);
-   bson_free (ret);
 }
 
 
-/*
- *--------------------------------------------------------------------------
- *
- * bson_string_truncate --
- *
- *       Truncate the string @string to @len bytes.
- *
- *       The underlying memory will be released via realloc() down to
- *       the minimum required size specified by @len.
- *
- * Returns:
- *       None.
- *
- * Side effects:
- *       None.
- *
- *--------------------------------------------------------------------------
- */
-
 void
 bson_string_truncate (bson_string_t *string, /* IN */
                       uint32_t len)          /* IN */
 {
-   uint32_t alloc;
+   /* Does not preserve UTF-8 validity; deprecated.
+    * Although the documentation only describes truncation as decreasing the length, we have undocumented requirements:
+    * the string may grow or shrink, and the buffer is expected to be allocated using the same power-of-two scheme as
+    * when growing to append. No effect if 'string' already has the requested length, regardless of the allocation size.
+    * When extending string length, this implementation is guaranteed to fill with NUL bytes. Previous versions left the
+    * new buffer contents undefined.
+    */
+   BSON_ASSERT_PARAM (string);
+   BSON_ASSERT (len < UINT32_MAX);
 
-   BSON_ASSERT (string);
-   BSON_ASSERT (len < INT_MAX);
+   uint32_t old_len = string->len;
+   if (len != old_len) {
+      uint32_t alloc = mcommon_next_power_of_two_u32 (len + 1u);
+      char *buffer = bson_realloc (string->str, alloc);
+      string->str = buffer;
+      string->alloc = alloc;
+      string->len = len;
 
-   alloc = len + 1;
-
-   if (alloc < 16) {
-      alloc = 16;
+      if (len < old_len) {
+         buffer[len] = '\0';
+      } else {
+         memset (buffer + old_len, 0, len + 1 - old_len);
+      }
    }
-
-   if (!bson_is_power_of_two (alloc)) {
-      alloc = (uint32_t) bson_next_power_of_two ((size_t) alloc);
-   }
-
-   string->str = bson_realloc (string->str, alloc);
-   string->alloc = alloc;
-   string->len = len;
-
-   string->str[string->len] = '\0';
 }
 
 
@@ -471,11 +316,11 @@ bson_strndup (const char *str, /* IN */
 void
 bson_strfreev (char **str) /* IN */
 {
-   int i;
-
    if (str) {
-      for (i = 0; str[i]; i++)
-         bson_free (str[i]);
+      for (char **ptr = str; *ptr != NULL; ++ptr) {
+         bson_free (*ptr);
+      }
+
       bson_free (str);
    }
 }
@@ -545,8 +390,12 @@ bson_strncpy (char *dst,       /* IN */
       return;
    }
 
+/* Prefer strncpy_s for MSVC, or strlcpy, which has additional checks and only
+ * adds one trailing \0 */
 #ifdef _MSC_VER
    strncpy_s (dst, size, src, _TRUNCATE);
+#elif defined(BSON_HAVE_STRLCPY)
+   strlcpy (dst, src, size);
 #else
    strncpy (dst, src, size);
    dst[size - 1] = '\0';
@@ -707,7 +556,7 @@ bson_ascii_strtoll (const char *s, char **e, int base)
 
    c = *tok;
 
-   while (isspace (c)) {
+   while (bson_isspace (c)) {
       c = *++tok;
    }
 
@@ -722,8 +571,7 @@ bson_ascii_strtoll (const char *s, char **e, int base)
    }
 
    /* from here down, inspired by NetBSD's strtoll */
-   if ((base == 0 || base == 16) && c == '0' &&
-       (tok[1] == 'x' || tok[1] == 'X')) {
+   if ((base == 0 || base == 16) && c == '0' && (tok[1] == 'x' || tok[1] == 'X')) {
       tok += 2;
       c = *tok;
       base = 16;
@@ -806,3 +654,10 @@ bson_strcasecmp (const char *s1, const char *s2)
    return strcasecmp (s1, s2);
 #endif
 }
+
+
+bool
+bson_isspace (int c)
+{
+   return c >= -1 && c <= 255 && isspace (c);
+}
