@@ -10,12 +10,12 @@
 ** and struct tm by A. Jesse Jiryu Davis for MongoDB, Inc.
 */
 
-#include "bson/bson-compat.h"
-#include "bson/bson-macros.h"
-#include "bson/bson-timegm-private.h"
+#include <bson/bson-compat.h>
+#include <bson/bson-macros.h>
+#include <bson/bson-timegm-private.h>
 
-#include "errno.h"
-#include "string.h"
+#include <errno.h>
+#include <string.h>
 #include <stdint.h> /* for INT64_MAX and INT64_MIN */
 
 /* Unlike <ctype.h>'s isdigit, this also works if c < 0 | c > UCHAR_MAX. */
@@ -31,17 +31,7 @@
 #define ATTRIBUTE_FORMAT(spec) /* empty */
 #endif
 
-#if !defined _Noreturn && \
-   (!defined(__STDC_VERSION__) || __STDC_VERSION__ < 201112)
-#if 2 < __GNUC__ + (8 <= __GNUC_MINOR__)
-#define _Noreturn __attribute__((__noreturn__))
-#else
-#define _Noreturn
-#endif
-#endif
-
-#if (!defined(__STDC_VERSION__) || __STDC_VERSION__ < 199901) && \
-   !defined restrict
+#if !defined(__STDC_VERSION__) && !defined restrict
 #define restrict /* empty */
 #endif
 
@@ -136,8 +126,7 @@ static int64_t const time_t_max = INT64_MAX;
 #endif /* !defined TZ_ABBR_MAX_LEN */
 
 #ifndef TZ_ABBR_CHAR_SET
-#define TZ_ABBR_CHAR_SET \
-   "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789 :+-._"
+#define TZ_ABBR_CHAR_SET "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789 :+-._"
 #endif /* !defined TZ_ABBR_CHAR_SET */
 
 #ifndef TZ_ABBR_ERR_CHAR
@@ -181,7 +170,7 @@ struct ttinfo {            /* time type information */
 };
 
 struct lsinfo {          /* leap second information */
-   int64_t ls_trans;      /* transition time */
+   int64_t ls_trans;     /* transition time */
    int_fast64_t ls_corr; /* correction to apply */
 };
 
@@ -226,50 +215,49 @@ struct rule {
 */
 
 static void
-gmtload (struct state *sp);
+gmtload (struct state *const sp);
 static struct bson_tm *
-gmtsub (const int64_t *timep, int_fast32_t offset, struct bson_tm *tmp);
+gmtsub (const int64_t *const timep, const int_fast32_t offset, struct bson_tm *const tmp);
 static int64_t
-increment_overflow (int64_t *number, int64_t delta);
+increment_overflow (int64_t *const ip, int64_t j);
 static int64_t
-leaps_thru_end_of (int64_t y) ATTRIBUTE_PURE;
+leaps_thru_end_of (const int64_t y) ATTRIBUTE_PURE;
 static int64_t
-increment_overflow32 (int_fast32_t *number, int64_t delta);
+increment_overflow32 (int_fast32_t *const lp, int64_t const m);
 static int64_t
-normalize_overflow32 (int_fast32_t *tensptr, int64_t *unitsptr, int64_t base);
+normalize_overflow32 (int_fast32_t *const tensptr, int64_t *const unitsptr, const int64_t base);
 static int64_t
-normalize_overflow (int64_t *tensptr, int64_t *unitsptr, int64_t base);
+normalize_overflow (int64_t *const tensptr, int64_t *const unitsptr, const int64_t base);
 static int64_t
-time1 (struct bson_tm *tmp,
-       struct bson_tm *(*funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
-       int_fast32_t offset);
+time1 (struct bson_tm *const tmp,
+       struct bson_tm *(*const funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
+       const int_fast32_t offset);
 static int64_t
-time2 (struct bson_tm *tmp,
-       struct bson_tm *(*funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
-       int_fast32_t offset,
-       int64_t *okayp);
+time2 (struct bson_tm *const tmp,
+       struct bson_tm *(*const funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
+       const int_fast32_t offset,
+       int64_t *const okayp);
 static int64_t
-time2sub (struct bson_tm *tmp,
-          struct bson_tm *(*funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
-          int_fast32_t offset,
-          int64_t *okayp,
-          int64_t do_norm_secs);
+time2sub (struct bson_tm *const tmp,
+          struct bson_tm *(*const funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
+          const int_fast32_t offset,
+          int64_t *const okayp,
+          const int64_t do_norm_secs);
 static struct bson_tm *
-timesub (const int64_t *timep,
-         int_fast32_t offset,
-         const struct state *sp,
-         struct bson_tm *tmp);
+timesub (const int64_t *const timep,
+         const int_fast32_t offset,
+         const struct state *const sp,
+         struct bson_tm *const tmp);
 static int64_t
-tmcomp (const struct bson_tm *atmp, const struct bson_tm *btmp);
+tmcomp (const struct bson_tm *const atmp, const struct bson_tm *const btmp);
 
 static struct state gmtmem;
 #define gmtptr (&gmtmem)
 
 static int gmt_is_set;
 
-static const int mon_lengths[2][MONSPERYEAR] = {
-   {31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31},
-   {31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}};
+static const int mon_lengths[2][MONSPERYEAR] = {{31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31},
+                                                {31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31}};
 
 static const int year_lengths[2] = {DAYSPERNYEAR, DAYSPERLYEAR};
 
@@ -289,11 +277,9 @@ gmtload (struct state *const sp)
 */
 
 static struct bson_tm *
-gmtsub (const int64_t *const timep,
-        const int_fast32_t offset,
-        struct bson_tm *const tmp)
+gmtsub (const int64_t *const timep, const int_fast32_t offset, struct bson_tm *const tmp)
 {
-   register struct bson_tm *result;
+   struct bson_tm *result;
 
    if (!gmt_is_set) {
       gmt_is_set = true;
@@ -317,27 +303,23 @@ gmtsub (const int64_t *const timep,
 */
 
 static int64_t
-leaps_thru_end_of (register const int64_t y)
+leaps_thru_end_of (const int64_t y)
 {
-   return (y >= 0) ? (y / 4 - y / 100 + y / 400)
-                   : -(leaps_thru_end_of (-(y + 1)) + 1);
+   return (y >= 0) ? (y / 4 - y / 100 + y / 400) : -(leaps_thru_end_of (-(y + 1)) + 1);
 }
 
 static struct bson_tm *
-timesub (const int64_t *const timep,
-         const int_fast32_t offset,
-         register const struct state *const sp,
-         register struct bson_tm *const tmp)
+timesub (const int64_t *const timep, const int_fast32_t offset, const struct state *const sp, struct bson_tm *const tmp)
 {
-   register const struct lsinfo *lp;
-   register int64_t tdays;
-   register int64_t idays; /* unsigned would be so 2003 */
-   register int_fast64_t rem;
+   const struct lsinfo *lp;
+   int64_t tdays;
+   int64_t idays; /* unsigned would be so 2003 */
+   int_fast64_t rem;
    int64_t y;
-   register const int *ip;
-   register int_fast64_t corr;
-   register int64_t hit;
-   register int64_t i;
+   const int (*ip)[MONSPERYEAR];
+   int_fast64_t corr;
+   int64_t hit;
+   int64_t i;
 
    corr = 0;
    hit = 0;
@@ -346,11 +328,9 @@ timesub (const int64_t *const timep,
       lp = &sp->lsis[i];
       if (*timep >= lp->ls_trans) {
          if (*timep == lp->ls_trans) {
-            hit = ((i == 0 && lp->ls_corr > 0) ||
-                   lp->ls_corr > sp->lsis[i - 1].ls_corr);
+            hit = ((i == 0 && lp->ls_corr > 0) || lp->ls_corr > sp->lsis[i - 1].ls_corr);
             if (hit)
-               while (i > 0 &&
-                      sp->lsis[i].ls_trans == sp->lsis[i - 1].ls_trans + 1 &&
+               while (i > 0 && sp->lsis[i].ls_trans == sp->lsis[i - 1].ls_trans + 1 &&
                       sp->lsis[i].ls_corr == sp->lsis[i - 1].ls_corr + 1) {
                   ++hit;
                   --i;
@@ -365,9 +345,9 @@ timesub (const int64_t *const timep,
    rem = *timep - tdays * SECSPERDAY;
    while (tdays < 0 || tdays >= year_lengths[isleap (y)]) {
       int64_t newy;
-      register int64_t tdelta;
-      register int64_t idelta;
-      register int64_t leapdays;
+      int64_t tdelta;
+      int64_t idelta;
+      int64_t leapdays;
 
       tdelta = tdays / DAYSPERLYEAR;
       idelta = tdelta;
@@ -382,7 +362,7 @@ timesub (const int64_t *const timep,
       y = newy;
    }
    {
-      register int_fast32_t seconds;
+      int_fast32_t seconds;
 
       seconds = (int_fast32_t) (tdays * SECSPERDAY);
       tdays = seconds / SECSPERDAY;
@@ -418,10 +398,8 @@ timesub (const int64_t *const timep,
    /*
    ** The "extra" mods below avoid overflow problems.
    */
-   tmp->tm_wday =
-      EPOCH_WDAY +
-      ((y - EPOCH_YEAR) % DAYSPERWEEK) * (DAYSPERNYEAR % DAYSPERWEEK) +
-      leaps_thru_end_of (y - 1) - leaps_thru_end_of (EPOCH_YEAR - 1) + idays;
+   tmp->tm_wday = EPOCH_WDAY + ((y - EPOCH_YEAR) % DAYSPERWEEK) * (DAYSPERNYEAR % DAYSPERWEEK) +
+                  leaps_thru_end_of (y - 1) - leaps_thru_end_of (EPOCH_YEAR - 1) + idays;
    tmp->tm_wday %= DAYSPERWEEK;
    if (tmp->tm_wday < 0)
       tmp->tm_wday += DAYSPERWEEK;
@@ -433,9 +411,12 @@ timesub (const int64_t *const timep,
    ** representation. This uses "... ??:59:60" et seq.
    */
    tmp->tm_sec = (int64_t) (rem % SECSPERMIN) + hit;
-   ip = mon_lengths[isleap (y)];
-   for (tmp->tm_mon = 0; idays >= ip[tmp->tm_mon]; ++(tmp->tm_mon))
-      idays -= ip[tmp->tm_mon];
+   ip = mon_lengths + (isleap (y) ? 1 : 0);
+   tmp->tm_mon = 0;
+   while (idays >= (*ip)[tmp->tm_mon]) {
+      idays -= (*ip)[tmp->tm_mon++];
+      BSON_ASSERT (tmp->tm_mon < MONSPERYEAR);
+   }
    tmp->tm_mday = (int64_t) (idays + 1);
    tmp->tm_isdst = 0;
 #ifdef TM_GMTOFF
@@ -464,7 +445,7 @@ timesub (const int64_t *const timep,
 static int64_t
 increment_overflow (int64_t *const ip, int64_t j)
 {
-   register int64_t const i = *ip;
+   int64_t const i = *ip;
 
    /*
    ** If i >= 0 there can only be overflow if i + j > INT_MAX
@@ -481,50 +462,43 @@ increment_overflow (int64_t *const ip, int64_t j)
 static int64_t
 increment_overflow32 (int_fast32_t *const lp, int64_t const m)
 {
-   register int_fast32_t const l = *lp;
+   int_fast32_t const l = *lp;
 
    if ((l >= 0) ? (m > INT_FAST32_MAX - l) : (m < INT_FAST32_MIN - l))
       return true;
-   *lp += m;
+   *lp += (int_fast32_t) m;
    return false;
 }
 
 static int64_t
 normalize_overflow (int64_t *const tensptr, int64_t *const unitsptr, const int64_t base)
 {
-   register int64_t tensdelta;
+   int64_t tensdelta;
 
-   tensdelta =
-      (*unitsptr >= 0) ? (*unitsptr / base) : (-1 - (-1 - *unitsptr) / base);
+   tensdelta = (*unitsptr >= 0) ? (*unitsptr / base) : (-1 - (-1 - *unitsptr) / base);
    *unitsptr -= tensdelta * base;
    return increment_overflow (tensptr, tensdelta);
 }
 
 static int64_t
-normalize_overflow32 (int_fast32_t *const tensptr,
-                      int64_t *const unitsptr,
-                      const int64_t base)
+normalize_overflow32 (int_fast32_t *const tensptr, int64_t *const unitsptr, const int64_t base)
 {
-   register int64_t tensdelta;
+   int64_t tensdelta;
 
-   tensdelta =
-      (*unitsptr >= 0) ? (*unitsptr / base) : (-1 - (-1 - *unitsptr) / base);
+   tensdelta = (*unitsptr >= 0) ? (*unitsptr / base) : (-1 - (-1 - *unitsptr) / base);
    *unitsptr -= tensdelta * base;
    return increment_overflow32 (tensptr, tensdelta);
 }
 
 static int64_t
-tmcomp (register const struct bson_tm *const atmp,
-        register const struct bson_tm *const btmp)
+tmcomp (const struct bson_tm *const atmp, const struct bson_tm *const btmp)
 {
-   register int64_t result;
+   int64_t result;
 
    if (atmp->tm_year != btmp->tm_year)
       return atmp->tm_year < btmp->tm_year ? -1 : 1;
-   if ((result = (atmp->tm_mon - btmp->tm_mon)) == 0 &&
-       (result = (atmp->tm_mday - btmp->tm_mday)) == 0 &&
-       (result = (atmp->tm_hour - btmp->tm_hour)) == 0 &&
-       (result = (atmp->tm_min - btmp->tm_min)) == 0)
+   if ((result = (atmp->tm_mon - btmp->tm_mon)) == 0 && (result = (atmp->tm_mday - btmp->tm_mday)) == 0 &&
+       (result = (atmp->tm_hour - btmp->tm_hour)) == 0 && (result = (atmp->tm_min - btmp->tm_min)) == 0)
       result = atmp->tm_sec - btmp->tm_sec;
    return result;
 }
@@ -536,13 +510,13 @@ time2sub (struct bson_tm *const tmp,
           int64_t *const okayp,
           const int64_t do_norm_secs)
 {
-   register const struct state *sp;
-   register int64_t dir;
-   register int64_t i, j;
-   register int64_t saved_seconds;
-   register int_fast32_t li;
-   register int64_t lo;
-   register int64_t hi;
+   const struct state *sp;
+   int64_t dir;
+   int64_t i, j;
+   int64_t saved_seconds;
+   int_fast32_t li;
+   int64_t lo;
+   int64_t hi;
    int_fast32_t y;
    int64_t newt;
    int64_t t;
@@ -720,12 +694,12 @@ time1 (struct bson_tm *const tmp,
        struct bson_tm *(*const funcp) (const int64_t *, int_fast32_t, struct bson_tm *),
        const int_fast32_t offset)
 {
-   register int64_t t;
-   register const struct state *sp;
-   register int64_t samei, otheri;
-   register int64_t sameind, otherind;
-   register int64_t i;
-   register int64_t nseen;
+   int64_t t;
+   const struct state *sp;
+   int64_t samei, otheri;
+   int64_t sameind, otherind;
+   int64_t i;
+   int64_t nseen;
    int64_t seen[TZ_MAX_TYPES];
    int64_t types[TZ_MAX_TYPES];
    int64_t okay;
@@ -792,4 +766,3 @@ _bson_timegm (struct bson_tm *const tmp)
       tmp->tm_isdst = 0;
    return time1 (tmp, gmtsub, 0L);
 }
-
