@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,33 +20,34 @@
 
 #define BSON_INSIDE
 
-#include "bson/bson-compat.h"
+#include <bson/bson-compat.h>
 
 #include <string.h>
 #include <time.h>
 
-#include "bson/bson-macros.h"
-#include "bson/bson-config.h"
-#include "bson/bson-atomic.h"
-#include "bson/bson-context.h"
-#include "bson/bson-clock.h"
-#include "bson/bson-decimal128.h"
-#include "bson/bson-error.h"
-#include "bson/bson-iter.h"
-#include "bson/bson-json.h"
-#include "bson/bson-keys.h"
-#include "bson/bson-md5.h"
-#include "bson/bson-memory.h"
-#include "bson/bson-oid.h"
-#include "bson/bson-reader.h"
-#include "bson/bson-string.h"
-#include "bson/bson-types.h"
-#include "bson/bson-utf8.h"
-#include "bson/bson-value.h"
-#include "bson/bson-version.h"
-#include "bson/bson-version-functions.h"
-#include "bson/bson-writer.h"
-#include "bson/bcon.h"
+#include <bson/bson-macros.h>
+#include <bson/bson-config.h>
+#include <bson/bson-atomic.h> // Deprecated.
+#include <bson/bson-cmp.h>    // Deprecated.
+#include <bson/bson-context.h>
+#include <bson/bson-clock.h>
+#include <bson/bson-decimal128.h>
+#include <bson/bson-error.h>
+#include <bson/bson-iter.h>
+#include <bson/bson-json.h>
+#include <bson/bson-keys.h>
+#include <bson/bson-md5.h>
+#include <bson/bson-memory.h>
+#include <bson/bson-oid.h>
+#include <bson/bson-reader.h>
+#include <bson/bson-string.h>
+#include <bson/bson-types.h>
+#include <bson/bson-utf8.h>
+#include <bson/bson-value.h>
+#include <bson/bson-version.h>
+#include <bson/bson-version-functions.h>
+#include <bson/bson-writer.h>
+#include <bson/bcon.h>
 
 #undef BSON_INSIDE
 
@@ -99,82 +100,58 @@ BSON_BEGIN_DECLS
 #define BSON_MAX_SIZE ((size_t) ((1U << 31) - 1))
 
 
-#define BSON_APPEND_ARRAY(b, key, val) \
-   bson_append_array (b, key, (int) strlen (key), val)
+#define BSON_APPEND_ARRAY(b, key, val) bson_append_array (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_ARRAY_BEGIN(b, key, child) \
-   bson_append_array_begin (b, key, (int) strlen (key), child)
+#define BSON_APPEND_ARRAY_BEGIN(b, key, child) bson_append_array_begin (b, key, (int) strlen (key), child)
 
-#define BSON_APPEND_BINARY(b, key, subtype, val, len) \
-   bson_append_binary (b, key, (int) strlen (key), subtype, val, len)
+#define BSON_APPEND_BINARY(b, key, subtype, val, len) bson_append_binary (b, key, (int) strlen (key), subtype, val, len)
 
-#define BSON_APPEND_BOOL(b, key, val) \
-   bson_append_bool (b, key, (int) strlen (key), val)
+#define BSON_APPEND_BOOL(b, key, val) bson_append_bool (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_CODE(b, key, val) \
-   bson_append_code (b, key, (int) strlen (key), val)
+#define BSON_APPEND_CODE(b, key, val) bson_append_code (b, key, (int) strlen (key), val)
 
 #define BSON_APPEND_CODE_WITH_SCOPE(b, key, val, scope) \
    bson_append_code_with_scope (b, key, (int) strlen (key), val, scope)
 
-#define BSON_APPEND_DBPOINTER(b, key, coll, oid) \
-   bson_append_dbpointer (b, key, (int) strlen (key), coll, oid)
+#define BSON_APPEND_DBPOINTER(b, key, coll, oid) bson_append_dbpointer (b, key, (int) strlen (key), coll, oid)
 
-#define BSON_APPEND_DOCUMENT_BEGIN(b, key, child) \
-   bson_append_document_begin (b, key, (int) strlen (key), child)
+#define BSON_APPEND_DOCUMENT_BEGIN(b, key, child) bson_append_document_begin (b, key, (int) strlen (key), child)
 
-#define BSON_APPEND_DOUBLE(b, key, val) \
-   bson_append_double (b, key, (int) strlen (key), val)
+#define BSON_APPEND_DOUBLE(b, key, val) bson_append_double (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_DOCUMENT(b, key, val) \
-   bson_append_document (b, key, (int) strlen (key), val)
+#define BSON_APPEND_DOCUMENT(b, key, val) bson_append_document (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_INT32(b, key, val) \
-   bson_append_int32 (b, key, (int) strlen (key), val)
+#define BSON_APPEND_INT32(b, key, val) bson_append_int32 (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_INT64(b, key, val) \
-   bson_append_int64 (b, key, (int) strlen (key), val)
+#define BSON_APPEND_INT64(b, key, val) bson_append_int64 (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_MINKEY(b, key) \
-   bson_append_minkey (b, key, (int) strlen (key))
+#define BSON_APPEND_MINKEY(b, key) bson_append_minkey (b, key, (int) strlen (key))
 
-#define BSON_APPEND_DECIMAL128(b, key, val) \
-   bson_append_decimal128 (b, key, (int) strlen (key), val)
+#define BSON_APPEND_DECIMAL128(b, key, val) bson_append_decimal128 (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_MAXKEY(b, key) \
-   bson_append_maxkey (b, key, (int) strlen (key))
+#define BSON_APPEND_MAXKEY(b, key) bson_append_maxkey (b, key, (int) strlen (key))
 
 #define BSON_APPEND_NULL(b, key) bson_append_null (b, key, (int) strlen (key))
 
-#define BSON_APPEND_OID(b, key, val) \
-   bson_append_oid (b, key, (int) strlen (key), val)
+#define BSON_APPEND_OID(b, key, val) bson_append_oid (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_REGEX(b, key, val, opt) \
-   bson_append_regex (b, key, (int) strlen (key), val, opt)
+#define BSON_APPEND_REGEX(b, key, val, opt) bson_append_regex (b, key, (int) strlen (key), val, opt)
 
-#define BSON_APPEND_UTF8(b, key, val) \
-   bson_append_utf8 (b, key, (int) strlen (key), val, (int) strlen (val))
+#define BSON_APPEND_UTF8(b, key, val) bson_append_utf8 (b, key, (int) strlen (key), val, (int) strlen (val))
 
-#define BSON_APPEND_SYMBOL(b, key, val) \
-   bson_append_symbol (b, key, (int) strlen (key), val, (int) strlen (val))
+#define BSON_APPEND_SYMBOL(b, key, val) bson_append_symbol (b, key, (int) strlen (key), val, (int) strlen (val))
 
-#define BSON_APPEND_TIME_T(b, key, val) \
-   bson_append_time_t (b, key, (int) strlen (key), val)
+#define BSON_APPEND_TIME_T(b, key, val) bson_append_time_t (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_TIMEVAL(b, key, val) \
-   bson_append_timeval (b, key, (int) strlen (key), val)
+#define BSON_APPEND_TIMEVAL(b, key, val) bson_append_timeval (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_DATE_TIME(b, key, val) \
-   bson_append_date_time (b, key, (int) strlen (key), val)
+#define BSON_APPEND_DATE_TIME(b, key, val) bson_append_date_time (b, key, (int) strlen (key), val)
 
-#define BSON_APPEND_TIMESTAMP(b, key, val, inc) \
-   bson_append_timestamp (b, key, (int) strlen (key), val, inc)
+#define BSON_APPEND_TIMESTAMP(b, key, val, inc) bson_append_timestamp (b, key, (int) strlen (key), val, inc)
 
-#define BSON_APPEND_UNDEFINED(b, key) \
-   bson_append_undefined (b, key, (int) strlen (key))
+#define BSON_APPEND_UNDEFINED(b, key) bson_append_undefined (b, key, (int) strlen (key))
 
-#define BSON_APPEND_VALUE(b, key, val) \
-   bson_append_value (b, key, (int) strlen (key), (val))
+#define BSON_APPEND_VALUE(b, key, val) bson_append_value (b, key, (int) strlen (key), (val))
 
 
 /**
@@ -195,10 +172,7 @@ bson_new_from_json (const uint8_t *data, ssize_t len, bson_error_t *error);
 
 
 BSON_EXPORT (bool)
-bson_init_from_json (bson_t *bson,
-                     const char *data,
-                     ssize_t len,
-                     bson_error_t *error);
+bson_init_from_json (bson_t *bson, const char *data, ssize_t len, bson_error_t *error);
 
 
 /**
@@ -277,10 +251,7 @@ bson_new_from_data (const uint8_t *data, size_t length);
  *          The underlying buffer will be used and not be freed in destroy.
  */
 BSON_EXPORT (bson_t *)
-bson_new_from_buffer (uint8_t **buf,
-                      size_t *buf_len,
-                      bson_realloc_func realloc_func,
-                      void *realloc_func_ctx);
+bson_new_from_buffer (uint8_t **buf, size_t *buf_len, bson_realloc_func realloc_func, void *realloc_func_ctx);
 
 
 /**
@@ -332,10 +303,7 @@ bson_copy_to (const bson_t *src, bson_t *dst);
  * on dst.
  */
 BSON_EXPORT (void)
-bson_copy_to_excluding (const bson_t *src,
-                        bson_t *dst,
-                        const char *first_exclude,
-                        ...) BSON_GNUC_NULL_TERMINATED
+bson_copy_to_excluding (const bson_t *src, bson_t *dst, const char *first_exclude, ...) BSON_GNUC_NULL_TERMINATED
    BSON_GNUC_DEPRECATED_FOR (bson_copy_to_excluding_noinit);
 
 /**
@@ -349,16 +317,12 @@ bson_copy_to_excluding (const bson_t *src,
  * old function is left for backwards compatibility.
  */
 BSON_EXPORT (void)
-bson_copy_to_excluding_noinit (const bson_t *src,
-                               bson_t *dst,
-                               const char *first_exclude,
-                               ...) BSON_GNUC_NULL_TERMINATED;
+bson_copy_to_excluding_noinit (const bson_t *src, bson_t *dst, const char *first_exclude, ...)
+   BSON_GNUC_NULL_TERMINATED;
 
 BSON_EXPORT (void)
-bson_copy_to_excluding_noinit_va (const bson_t *src,
-                                  bson_t *dst,
-                                  const char *first_exclude,
-                                  va_list args);
+bson_copy_to_excluding_noinit_va (const bson_t *src, bson_t *dst, const char *first_exclude, va_list args);
+
 
 /**
  * bson_destroy:
@@ -450,7 +414,7 @@ BSON_EXPORT (int)
 bson_compare (const bson_t *bson, const bson_t *other);
 
 /*
- * bson_compare:
+ * bson_equal:
  * @bson: A bson_t.
  * @other: A bson_t.
  *
@@ -487,9 +451,49 @@ bson_validate (const bson_t *bson, bson_validate_flags_t flags, size_t *offset);
  * Returns: true if @bson is valid; otherwise false and @error is filled out.
  */
 BSON_EXPORT (bool)
-bson_validate_with_error (const bson_t *bson,
-                          bson_validate_flags_t flags,
-                          bson_error_t *error);
+bson_validate_with_error (const bson_t *bson, bson_validate_flags_t flags, bson_error_t *error);
+
+
+/**
+ * bson_validate_with_error_and_offset:
+ * @bson: A bson_t.
+ * @offset: A location for the error offset.
+ * @error: A location for the error info.
+ *
+ * Validates a BSON document by walking through the document and inspecting
+ * the fields for valid content.
+ *
+ * Returns: true if @bson is valid; otherwise false, @offset is set
+ * and @error is filled out.
+ */
+BSON_EXPORT (bool)
+bson_validate_with_error_and_offset (const bson_t *bson,
+                                     bson_validate_flags_t flags,
+                                     size_t *offset,
+                                     bson_error_t *error);
+
+
+/**
+ * bson_as_json_with_opts:
+ * @bson: A bson_t.
+ * @length: A location for the string length, or NULL.
+ * @opts: A bson_t_json_opts_t defining options for the conversion
+ *
+ * Creates a new string containing @bson in the selected JSON format,
+ * conforming to the MongoDB Extended JSON Spec:
+ *
+ * github.com/mongodb/specifications/blob/master/source/extended-json.rst
+ *
+ * The caller is responsible for freeing the resulting string. If @length is
+ * non-NULL, then the length of the resulting string will be placed in @length.
+ *
+ * See https://www.mongodb.com/docs/manual/reference/mongodb-extended-json/ for
+ * more information on extended JSON.
+ *
+ * Returns: A newly allocated string that should be freed with bson_free().
+ */
+BSON_EXPORT (char *)
+bson_as_json_with_opts (const bson_t *bson, size_t *length, const bson_json_opts_t *opts);
 
 
 /**
@@ -505,7 +509,7 @@ bson_validate_with_error (const bson_t *bson,
  * The caller is responsible for freeing the resulting string. If @length is
  * non-NULL, then the length of the resulting string will be placed in @length.
  *
- * See http://docs.mongodb.org/manual/reference/mongodb-extended-json/ for
+ * See https://www.mongodb.com/docs/manual/reference/mongodb-extended-json/ for
  * more information on extended JSON.
  *
  * Returns: A newly allocated string that should be freed with bson_free().
@@ -528,7 +532,11 @@ bson_as_canonical_extended_json (const bson_t *bson, size_t *length);
  * Returns: A newly allocated string that should be freed with bson_free().
  */
 BSON_EXPORT (char *)
-bson_as_json (const bson_t *bson, size_t *length);
+bson_as_json (const bson_t *bson, size_t *length) BSON_GNUC_DEPRECATED_FOR (bson_as_legacy_extended_json);
+
+// `bson_as_legacy_extended_json` is a non-deprecated form of `bson_as_json`.
+BSON_EXPORT (char *)
+bson_as_legacy_extended_json (const bson_t *bson, size_t *length);
 
 
 /**
@@ -544,7 +552,7 @@ bson_as_json (const bson_t *bson, size_t *length);
  * The caller is responsible for freeing the resulting string. If @length is
  * non-NULL, then the length of the resulting string will be placed in @length.
  *
- * See http://docs.mongodb.org/manual/reference/mongodb-extended-json/ for
+ * See https://www.mongodb.com/docs/manual/reference/mongodb-extended-json/ for
  * more information on extended JSON.
  *
  * Returns: A newly allocated string that should be freed with bson_free().
@@ -555,15 +563,47 @@ bson_as_relaxed_extended_json (const bson_t *bson, size_t *length);
 
 /* like bson_as_json() but for outermost arrays. */
 BSON_EXPORT (char *)
-bson_array_as_json (const bson_t *bson, size_t *length);
+bson_array_as_json (const bson_t *bson, size_t *length) BSON_GNUC_DEPRECATED_FOR (bson_array_as_legacy_extended_json);
 
+// `bson_array_as_legacy_extended_json` is a non-deprecated form of `bson_array_as_json`.
+BSON_EXPORT (char *)
+bson_array_as_legacy_extended_json (const bson_t *bson, size_t *length);
+
+
+/* like bson_as_relaxed_extended_json() but for outermost arrays. */
+BSON_EXPORT (char *)
+bson_array_as_relaxed_extended_json (const bson_t *bson, size_t *length);
+
+
+/* like bson_as_canonical_extended_json() but for outermost arrays. */
+BSON_EXPORT (char *)
+bson_array_as_canonical_extended_json (const bson_t *bson, size_t *length);
+
+// bson_array_builder_t defines an API for building arrays.
+// BSON arrays require sequential numeric keys "0", "1", "2", ...
+typedef struct _bson_array_builder_t bson_array_builder_t;
+
+// bson_array_builder_new may be used to build a top-level BSON array. Example:
+// `[1,2,3]`.
+// To append an array field to a document (Example: `{ "field": [1,2,3] }`), use
+// `bson_append_array_builder_begin`.
+BSON_EXPORT (bson_array_builder_t *) bson_array_builder_new (void);
+
+// bson_array_builder_build initializes and moves BSON data to `out`.
+// `bab` may be reused and will start appending a new array at index "0".
+BSON_EXPORT (bool)
+bson_array_builder_build (bson_array_builder_t *bab, bson_t *out);
+
+BSON_EXPORT (void)
+bson_array_builder_destroy (bson_array_builder_t *bab);
 
 BSON_EXPORT (bool)
-bson_append_value (bson_t *bson,
-                   const char *key,
-                   int key_length,
-                   const bson_value_t *value);
+bson_append_value (bson_t *bson, const char *key, int key_length, const bson_value_t *value);
 
+#define BSON_APPEND_VALUE(b, key, val) bson_append_value (b, key, (int) strlen (key), (val))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_value (bson_array_builder_t *bab, const bson_value_t *value);
 
 /**
  * bson_append_array:
@@ -578,11 +618,12 @@ bson_append_value (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_array (bson_t *bson,
-                   const char *key,
-                   int key_length,
-                   const bson_t *array);
+bson_append_array (bson_t *bson, const char *key, int key_length, const bson_t *array);
 
+#define BSON_APPEND_ARRAY(b, key, val) bson_append_array (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_array (bson_array_builder_t *bab, const bson_t *array);
 
 /**
  * bson_append_binary:
@@ -597,13 +638,16 @@ bson_append_array (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_binary (bson_t *bson,
-                    const char *key,
-                    int key_length,
-                    bson_subtype_t subtype,
-                    const uint8_t *binary,
-                    uint32_t length);
+bson_append_binary (
+   bson_t *bson, const char *key, int key_length, bson_subtype_t subtype, const uint8_t *binary, uint32_t length);
 
+#define BSON_APPEND_BINARY(b, key, subtype, val, len) bson_append_binary (b, key, (int) strlen (key), subtype, val, len)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_binary (bson_array_builder_t *bab,
+                                  bson_subtype_t subtype,
+                                  const uint8_t *binary,
+                                  uint32_t length);
 
 /**
  * bson_append_bool:
@@ -618,6 +662,10 @@ bson_append_binary (bson_t *bson,
 BSON_EXPORT (bool)
 bson_append_bool (bson_t *bson, const char *key, int key_length, bool value);
 
+#define BSON_APPEND_BOOL(b, key, val) bson_append_bool (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_bool (bson_array_builder_t *bab, bool value);
 
 /**
  * bson_append_code:
@@ -631,11 +679,12 @@ bson_append_bool (bson_t *bson, const char *key, int key_length, bool value);
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_code (bson_t *bson,
-                  const char *key,
-                  int key_length,
-                  const char *javascript);
+bson_append_code (bson_t *bson, const char *key, int key_length, const char *javascript);
 
+#define BSON_APPEND_CODE(b, key, val) bson_append_code (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_code (bson_array_builder_t *bab, const char *javascript);
 
 /**
  * bson_append_code_with_scope:
@@ -650,12 +699,14 @@ bson_append_code (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_code_with_scope (bson_t *bson,
-                             const char *key,
-                             int key_length,
-                             const char *javascript,
-                             const bson_t *scope);
+bson_append_code_with_scope (
+   bson_t *bson, const char *key, int key_length, const char *javascript, const bson_t *scope);
 
+#define BSON_APPEND_CODE_WITH_SCOPE(b, key, val, scope) \
+   bson_append_code_with_scope (b, key, (int) strlen (key), val, scope)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_code_with_scope (bson_array_builder_t *bab, const char *javascript, const bson_t *scope);
 
 /**
  * bson_append_dbpointer:
@@ -670,12 +721,12 @@ bson_append_code_with_scope (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_dbpointer (bson_t *bson,
-                       const char *key,
-                       int key_length,
-                       const char *collection,
-                       const bson_oid_t *oid);
+bson_append_dbpointer (bson_t *bson, const char *key, int key_length, const char *collection, const bson_oid_t *oid);
 
+#define BSON_APPEND_DBPOINTER(b, key, coll, oid) bson_append_dbpointer (b, key, (int) strlen (key), coll, oid)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_dbpointer (bson_array_builder_t *bab, const char *collection, const bson_oid_t *oid);
 
 /**
  * bson_append_double:
@@ -687,11 +738,12 @@ bson_append_dbpointer (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_double (bson_t *bson,
-                    const char *key,
-                    int key_length,
-                    double value);
+bson_append_double (bson_t *bson, const char *key, int key_length, double value);
 
+#define BSON_APPEND_DOUBLE(b, key, val) bson_append_double (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_double (bson_array_builder_t *bab, double value);
 
 /**
  * bson_append_document:
@@ -705,11 +757,12 @@ bson_append_double (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_document (bson_t *bson,
-                      const char *key,
-                      int key_length,
-                      const bson_t *value);
+bson_append_document (bson_t *bson, const char *key, int key_length, const bson_t *value);
 
+#define BSON_APPEND_DOCUMENT(b, key, val) bson_append_document (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_document (bson_array_builder_t *bab, const bson_t *value);
 
 /**
  * bson_append_document_begin:
@@ -729,11 +782,12 @@ bson_append_document (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_document_begin (bson_t *bson,
-                            const char *key,
-                            int key_length,
-                            bson_t *child);
+bson_append_document_begin (bson_t *bson, const char *key, int key_length, bson_t *child);
 
+#define BSON_APPEND_DOCUMENT_BEGIN(b, key, child) bson_append_document_begin (b, key, (int) strlen (key), child)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_document_begin (bson_array_builder_t *bab, bson_t *child);
 
 /**
  * bson_append_document_end:
@@ -748,6 +802,9 @@ bson_append_document_begin (bson_t *bson,
 BSON_EXPORT (bool)
 bson_append_document_end (bson_t *bson, bson_t *child);
 
+BSON_EXPORT (bool)
+bson_array_builder_append_document_end (bson_array_builder_t *bab, bson_t *child);
+
 
 /**
  * bson_append_array_begin:
@@ -770,11 +827,9 @@ bson_append_document_end (bson_t *bson, bson_t *child);
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_array_begin (bson_t *bson,
-                         const char *key,
-                         int key_length,
-                         bson_t *child);
+bson_append_array_begin (bson_t *bson, const char *key, int key_length, bson_t *child);
 
+#define BSON_APPEND_ARRAY_BEGIN(b, key, child) bson_append_array_begin (b, key, (int) strlen (key), child)
 
 /**
  * bson_append_array_end:
@@ -801,11 +856,12 @@ bson_append_array_end (bson_t *bson, bson_t *child);
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_int32 (bson_t *bson,
-                   const char *key,
-                   int key_length,
-                   int32_t value);
+bson_append_int32 (bson_t *bson, const char *key, int key_length, int32_t value);
 
+#define BSON_APPEND_INT32(b, key, val) bson_append_int32 (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_int32 (bson_array_builder_t *bab, int32_t value);
 
 /**
  * bson_append_int64:
@@ -818,11 +874,12 @@ bson_append_int32 (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_int64 (bson_t *bson,
-                   const char *key,
-                   int key_length,
-                   int64_t value);
+bson_append_int64 (bson_t *bson, const char *key, int key_length, int64_t value);
 
+#define BSON_APPEND_INT64(b, key, val) bson_append_int64 (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_int64 (bson_array_builder_t *bab, int64_t value);
 
 /**
  * bson_append_decimal128:
@@ -835,11 +892,12 @@ bson_append_int64 (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_decimal128 (bson_t *bson,
-                        const char *key,
-                        int key_length,
-                        const bson_decimal128_t *value);
+bson_append_decimal128 (bson_t *bson, const char *key, int key_length, const bson_decimal128_t *value);
 
+#define BSON_APPEND_DECIMAL128(b, key, val) bson_append_decimal128 (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_decimal128 (bson_array_builder_t *bab, const bson_decimal128_t *value);
 
 /**
  * bson_append_iter:
@@ -854,11 +912,12 @@ bson_append_decimal128 (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_iter (bson_t *bson,
-                  const char *key,
-                  int key_length,
-                  const bson_iter_t *iter);
+bson_append_iter (bson_t *bson, const char *key, int key_length, const bson_iter_t *iter);
 
+#define BSON_APPEND_ITER(b, key, val) bson_append_iter (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_iter (bson_array_builder_t *bab, const bson_iter_t *iter);
 
 /**
  * bson_append_minkey:
@@ -875,6 +934,10 @@ bson_append_iter (bson_t *bson,
 BSON_EXPORT (bool)
 bson_append_minkey (bson_t *bson, const char *key, int key_length);
 
+#define BSON_APPEND_MINKEY(b, key) bson_append_minkey (b, key, (int) strlen (key))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_minkey (bson_array_builder_t *bab);
 
 /**
  * bson_append_maxkey:
@@ -891,6 +954,10 @@ bson_append_minkey (bson_t *bson, const char *key, int key_length);
 BSON_EXPORT (bool)
 bson_append_maxkey (bson_t *bson, const char *key, int key_length);
 
+#define BSON_APPEND_MAXKEY(b, key) bson_append_maxkey (b, key, (int) strlen (key))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_maxkey (bson_array_builder_t *bab);
 
 /**
  * bson_append_null:
@@ -904,6 +971,10 @@ bson_append_maxkey (bson_t *bson, const char *key, int key_length);
 BSON_EXPORT (bool)
 bson_append_null (bson_t *bson, const char *key, int key_length);
 
+#define BSON_APPEND_NULL(b, key) bson_append_null (b, key, (int) strlen (key))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_null (bson_array_builder_t *bab);
 
 /**
  * bson_append_oid:
@@ -917,11 +988,12 @@ bson_append_null (bson_t *bson, const char *key, int key_length);
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_oid (bson_t *bson,
-                 const char *key,
-                 int key_length,
-                 const bson_oid_t *oid);
+bson_append_oid (bson_t *bson, const char *key, int key_length, const bson_oid_t *oid);
 
+#define BSON_APPEND_OID(b, key, val) bson_append_oid (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_oid (bson_array_builder_t *bab, const bson_oid_t *oid);
 
 /**
  * bson_append_regex:
@@ -947,12 +1019,12 @@ bson_append_oid (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_regex (bson_t *bson,
-                   const char *key,
-                   int key_length,
-                   const char *regex,
-                   const char *options);
+bson_append_regex (bson_t *bson, const char *key, int key_length, const char *regex, const char *options);
 
+#define BSON_APPEND_REGEX(b, key, val, opt) bson_append_regex (b, key, (int) strlen (key), val, opt)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_regex (bson_array_builder_t *bab, const char *regex, const char *options);
 
 /**
  * bson_append_regex:
@@ -980,13 +1052,14 @@ bson_append_regex (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_regex_w_len (bson_t *bson,
-                         const char *key,
-                         int key_length,
-                         const char *regex,
-                         int regex_length,
-                         const char *options);
+bson_append_regex_w_len (
+   bson_t *bson, const char *key, int key_length, const char *regex, int regex_length, const char *options);
 
+BSON_EXPORT (bool)
+bson_array_builder_append_regex_w_len (bson_array_builder_t *bab,
+                                       const char *regex,
+                                       int regex_length,
+                                       const char *options);
 
 /**
  * bson_append_utf8:
@@ -1004,12 +1077,12 @@ bson_append_regex_w_len (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_utf8 (bson_t *bson,
-                  const char *key,
-                  int key_length,
-                  const char *value,
-                  int length);
+bson_append_utf8 (bson_t *bson, const char *key, int key_length, const char *value, int length);
 
+#define BSON_APPEND_UTF8(b, key, val) bson_append_utf8 (b, key, (int) strlen (key), val, (int) strlen (val))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_utf8 (bson_array_builder_t *bab, const char *value, int length);
 
 /**
  * bson_append_symbol:
@@ -1026,12 +1099,12 @@ bson_append_utf8 (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_symbol (bson_t *bson,
-                    const char *key,
-                    int key_length,
-                    const char *value,
-                    int length);
+bson_append_symbol (bson_t *bson, const char *key, int key_length, const char *value, int length);
 
+#define BSON_APPEND_SYMBOL(b, key, val) bson_append_symbol (b, key, (int) strlen (key), val, (int) strlen (val))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_symbol (bson_array_builder_t *bab, const char *value, int length);
 
 /**
  * bson_append_time_t:
@@ -1045,11 +1118,12 @@ bson_append_symbol (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_time_t (bson_t *bson,
-                    const char *key,
-                    int key_length,
-                    time_t value);
+bson_append_time_t (bson_t *bson, const char *key, int key_length, time_t value);
 
+#define BSON_APPEND_TIME_T(b, key, val) bson_append_time_t (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_time_t (bson_array_builder_t *bab, time_t value);
 
 /**
  * bson_append_timeval:
@@ -1063,11 +1137,12 @@ bson_append_time_t (bson_t *bson,
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_timeval (bson_t *bson,
-                     const char *key,
-                     int key_length,
-                     struct timeval *value);
+bson_append_timeval (bson_t *bson, const char *key, int key_length, struct timeval *value);
 
+#define BSON_APPEND_TIMEVAL(b, key, val) bson_append_timeval (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_timeval (bson_array_builder_t *bab, struct timeval *value);
 
 /**
  * bson_append_date_time:
@@ -1081,11 +1156,12 @@ bson_append_timeval (bson_t *bson,
  * Returns: true if successful; otherwise false.
  */
 BSON_EXPORT (bool)
-bson_append_date_time (bson_t *bson,
-                       const char *key,
-                       int key_length,
-                       int64_t value);
+bson_append_date_time (bson_t *bson, const char *key, int key_length, int64_t value);
 
+#define BSON_APPEND_DATE_TIME(b, key, val) bson_append_date_time (b, key, (int) strlen (key), val)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_date_time (bson_array_builder_t *bab, int64_t value);
 
 /**
  * bson_append_now_utc:
@@ -1101,6 +1177,11 @@ bson_append_date_time (bson_t *bson,
 BSON_EXPORT (bool)
 bson_append_now_utc (bson_t *bson, const char *key, int key_length);
 
+#define BSON_APPEND_NOW_UTC(b, key) bson_append_now_utc (b, key, (int) strlen (key))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_now_utc (bson_array_builder_t *bab);
+
 /**
  * bson_append_timestamp:
  * @bson: A bson_t.
@@ -1118,12 +1199,12 @@ bson_append_now_utc (bson_t *bson, const char *key, int key_length);
  * Returns: true if successful; false if append would overflow max size.
  */
 BSON_EXPORT (bool)
-bson_append_timestamp (bson_t *bson,
-                       const char *key,
-                       int key_length,
-                       uint32_t timestamp,
-                       uint32_t increment);
+bson_append_timestamp (bson_t *bson, const char *key, int key_length, uint32_t timestamp, uint32_t increment);
 
+#define BSON_APPEND_TIMESTAMP(b, key, val, inc) bson_append_timestamp (b, key, (int) strlen (key), val, inc)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_timestamp (bson_array_builder_t *bab, uint32_t timestamp, uint32_t increment);
 
 /**
  * bson_append_undefined:
@@ -1139,10 +1220,29 @@ bson_append_timestamp (bson_t *bson,
 BSON_EXPORT (bool)
 bson_append_undefined (bson_t *bson, const char *key, int key_length);
 
+#define BSON_APPEND_UNDEFINED(b, key) bson_append_undefined (b, key, (int) strlen (key))
+
+BSON_EXPORT (bool)
+bson_array_builder_append_undefined (bson_array_builder_t *bab);
 
 BSON_EXPORT (bool)
 bson_concat (bson_t *dst, const bson_t *src);
 
+BSON_EXPORT (bool)
+bson_append_array_builder_begin (bson_t *bson, const char *key, int key_length, bson_array_builder_t **child);
+
+#define BSON_APPEND_ARRAY_BUILDER_BEGIN(b, key, child) \
+   bson_append_array_builder_begin (b, key, (int) strlen (key), child)
+
+BSON_EXPORT (bool)
+bson_array_builder_append_array_builder_begin (bson_array_builder_t *bab, bson_array_builder_t **child);
+
+BSON_EXPORT (bool)
+bson_append_array_builder_end (bson_t *bson, bson_array_builder_t *child);
+
+BSON_EXPORT (bool)
+bson_array_builder_append_array_builder_end (bson_array_builder_t *bab, bson_array_builder_t *child);
+
 
 BSON_END_DECLS
 
