@@ -3,8 +3,8 @@
  * See included LICENSE file for license details.
  */
 
-#include "jsonsl.h"
-#include "bson/bson-memory.h"
+#include <jsonsl/jsonsl.h>
+#include <bson/bson-memory.h>
 
 #include <limits.h>
 #include <ctype.h>
@@ -284,13 +284,15 @@ jsonsl_feed(jsonsl_t jsn, const jsonsl_char_t *bytes, size_t nbytes)
         INVOKE_ERROR(HKEY_EXPECTED); \
     }
 
-#define VERIFY_SPECIAL(lit) \
-        if (CUR_CHAR != (lit)[jsn->pos - state->pos_begin]) { \
+#define VERIFY_SPECIAL(lit, lit_len) \
+        if ((jsn->pos - state->pos_begin) > lit_len \
+                || CUR_CHAR != (lit)[jsn->pos - state->pos_begin]) { \
             INVOKE_ERROR(SPECIAL_EXPECTED); \
         }
 
-#define VERIFY_SPECIAL_CI(lit) \
-        if (tolower(CUR_CHAR) != (lit)[jsn->pos - state->pos_begin]) { \
+#define VERIFY_SPECIAL_CI(lit, lit_len) \
+        if ((jsn->pos - state->pos_begin) > lit_len \
+                || tolower(CUR_CHAR) != (lit)[jsn->pos - state->pos_begin]) { \
             INVOKE_ERROR(SPECIAL_EXPECTED); \
         }
 
@@ -440,28 +442,38 @@ jsonsl_feed(jsonsl_t jsn, const jsonsl_char_t *bytes, size_t nbytes)
 
                 /* Verify TRUE, FALSE, NULL */
                 if (state->special_flags == JSONSL_SPECIALf_TRUE) {
-                    VERIFY_SPECIAL("true");
+                    VERIFY_SPECIAL("true", 4 /* strlen("true") */);
                 } else if (state->special_flags == JSONSL_SPECIALf_FALSE) {
-                    VERIFY_SPECIAL("false");
+                    VERIFY_SPECIAL("false", 5 /* strlen("false") */);
                 } else if (state->special_flags == JSONSL_SPECIALf_NULL) {
-                    VERIFY_SPECIAL("null");
+                    VERIFY_SPECIAL("null", 4 /* strlen("null") */);
 #ifdef JSONSL_PARSE_NAN
                 } else if (state->special_flags == JSONSL_SPECIALf_POS_INF) {
-                    VERIFY_SPECIAL_CI("infinity");
+                    VERIFY_SPECIAL_CI("infinity", 8 /* strlen("infinity") */);
                 } else if (state->special_flags == JSONSL_SPECIALf_NEG_INF) {
-                    VERIFY_SPECIAL_CI("-infinity");
+                    VERIFY_SPECIAL_CI("-infinity", 9 /* strlen("-infinity") */);
                 } else if (state->special_flags == JSONSL_SPECIALf_NAN) {
-                    VERIFY_SPECIAL_CI("nan");
+                    VERIFY_SPECIAL_CI("nan", 3 /* strlen("nan") */);
                 } else if (state->special_flags & JSONSL_SPECIALf_NULL ||
                            state->special_flags & JSONSL_SPECIALf_NAN) {
                    /* previous char was "n", are we parsing null or nan? */
-                   if (CUR_CHAR != 'u') {
+                   const bool not_u = CUR_CHAR != 'u';
+                   const bool not_a = tolower (CUR_CHAR) != 'a';
+                   if (not_u) {
                       state->special_flags &= ~JSONSL_SPECIALf_NULL;
                    }
-
-                   if (tolower(CUR_CHAR) != 'a') {
+                   if (not_a) {
                       state->special_flags &= ~JSONSL_SPECIALf_NAN;
                    }
+                   if (not_u && not_a) {
+                      /* This verify will always fail, as we have an 'n'
+                       * followed by a character that is neither 'a' nor 'u'
+                       * (and hence cannot be "null"). The purpose of this
+                       * VERIFY_SPECIAL is to generate an error in tokenization
+                       * that stops if a bare 'n' cannot possibly be a "nan" or
+                       * a "null". */
+                      VERIFY_SPECIAL ("null", 4);
+                   }
 #endif
                 }
                 INCR_METRIC(SPECIAL_FASTPATH);
