@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,13 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_APM_PRIVATE_H
 #define MONGOC_APM_PRIVATE_H
 
 #include <bson/bson.h>
-#include "mongoc-apm.h"
+#include <mongoc/mongoc-apm.h>
 
 BSON_BEGIN_DECLS
 
@@ -55,6 +55,8 @@ struct _mongoc_apm_command_started_t {
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
@@ -63,16 +65,20 @@ struct _mongoc_apm_command_succeeded_t {
    bson_t *reply;
    bool reply_owned;
    const char *command_name;
+   const char *database_name;
    int64_t request_id;
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
 struct _mongoc_apm_command_failed_t {
    int64_t duration;
    const char *command_name;
+   const char *database_name;
    const bson_error_t *error;
    bson_t *reply;
    bool reply_owned;
@@ -80,6 +86,8 @@ struct _mongoc_apm_command_failed_t {
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
@@ -155,6 +163,8 @@ mongoc_apm_command_started_init (mongoc_apm_command_started_t *event,
                                  int64_t operation_id,
                                  const mongoc_host_list_t *host,
                                  uint32_t server_id,
+                                 const bson_oid_t *service_id,
+                                 int64_t server_connection_id,
                                  bool *is_redacted, /* out */
                                  void *context);
 
@@ -173,10 +183,13 @@ mongoc_apm_command_succeeded_init (mongoc_apm_command_succeeded_t *event,
                                    int64_t duration,
                                    const bson_t *reply,
                                    const char *command_name,
+                                   const char *database_name,
                                    int64_t request_id,
                                    int64_t operation_id,
                                    const mongoc_host_list_t *host,
                                    uint32_t server_id,
+                                   const bson_oid_t *service_id,
+                                   int64_t server_connection_id,
                                    bool force_redaction,
                                    void *context);
 
@@ -187,24 +200,30 @@ void
 mongoc_apm_command_failed_init (mongoc_apm_command_failed_t *event,
                                 int64_t duration,
                                 const char *command_name,
+                                const char *database_name,
                                 const bson_error_t *error,
                                 const bson_t *reply,
                                 int64_t request_id,
                                 int64_t operation_id,
                                 const mongoc_host_list_t *host,
                                 uint32_t server_id,
+                                const bson_oid_t *service_id,
+                                int64_t server_connection_id,
                                 bool force_redaction,
                                 void *context);
 
 void
 mongoc_apm_command_failed_cleanup (mongoc_apm_command_failed_t *event);
 
+/**
+ * @brief Determine whether the given command-related message is a "sensitive
+ * command."
+ *
+ * @param command_name The name of the command being checked
+ * @param body The body of the command request, reply, or failure.
+ */
 bool
-mongoc_apm_is_sensitive_command (const char *command_name,
-                                 const bson_t *command);
-
-bool
-mongoc_apm_is_sensitive_reply (const char *command_name, const bson_t *reply);
+mongoc_apm_is_sensitive_command_message (const char *command_name, const bson_t *body);
 
 BSON_END_DECLS
 
