@@ -1,5 +1,5 @@
 /*
- * Copyright 2017-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,17 +14,17 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_CHANGE_STREAM_PRIVATE_H
 #define MONGOC_CHANGE_STREAM_PRIVATE_H
 
-#include "mongoc/mongoc-change-stream.h"
-#include "mongoc/mongoc-client-session.h"
-#include "mongoc/mongoc-collection.h"
-#include "mongoc/mongoc-cursor.h"
-#include "mongoc/mongoc-opts-private.h"
-#include "mongoc/mongoc-opts-helpers-private.h"
+#include <mongoc/mongoc-change-stream.h>
+#include <mongoc/mongoc-client-session.h>
+#include <mongoc/mongoc-collection.h>
+#include <mongoc/mongoc-cursor.h>
+#include <mongoc/mongoc-opts-private.h>
+#include <mongoc/mongoc-opts-helpers-private.h>
 
 typedef enum {
    MONGOC_CHANGE_STREAM_COLLECTION,
@@ -38,6 +38,8 @@ struct _mongoc_change_stream_t {
    bson_t pipeline_to_append;
    bson_t resume_token;
    bson_t *full_document;
+   bson_t *full_document_before_change;
+   bool show_expanded_events;
 
    bson_error_t err;
    bson_t err_doc;
@@ -49,8 +51,8 @@ struct _mongoc_change_stream_t {
    mongoc_read_concern_t *read_concern;
 
    mongoc_change_stream_type_t change_stream_type;
-   char db[140];
-   char coll[140];
+   char *db;
+   char *coll;
 
    int64_t max_await_time_ms;
    int32_t batch_size;
@@ -62,21 +64,18 @@ struct _mongoc_change_stream_t {
    bool resumed;
 
    mongoc_client_session_t *implicit_session;
+
+   /* The max_wire_version of the server the change stream is tied to. */
+   uint32_t max_wire_version;
 };
 
 mongoc_change_stream_t *
-_mongoc_change_stream_new_from_collection (const mongoc_collection_t *coll,
-                                           const bson_t *pipeline,
-                                           const bson_t *opts);
+_mongoc_change_stream_new_from_collection (const mongoc_collection_t *coll, const bson_t *pipeline, const bson_t *opts);
 
 mongoc_change_stream_t *
-_mongoc_change_stream_new_from_database (const mongoc_database_t *db,
-                                         const bson_t *pipeline,
-                                         const bson_t *opts);
+_mongoc_change_stream_new_from_database (const mongoc_database_t *db, const bson_t *pipeline, const bson_t *opts);
 
 mongoc_change_stream_t *
-_mongoc_change_stream_new_from_client (mongoc_client_t *client,
-                                       const bson_t *pipeline,
-                                       const bson_t *opts);
+_mongoc_change_stream_new_from_client (mongoc_client_t *client, const bson_t *pipeline, const bson_t *opts);
 
 #endif /* MONGOC_CHANGE_STREAM_PRIVATE_H */
