@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,15 +14,15 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_SECURE_TRANSPORT_PRIVATE_H
 #define MONGOC_SECURE_TRANSPORT_PRIVATE_H
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-ssl.h"
-#include "mongoc/mongoc-stream-tls-secure-transport-private.h"
+#include <mongoc/mongoc-ssl.h>
+#include <mongoc/mongoc-stream-tls-secure-transport-private.h>
 #include <Security/Security.h>
 
 
@@ -32,27 +32,22 @@ char *
 _mongoc_cfstringref_to_cstring (CFStringRef ref);
 
 char *
-_mongoc_secure_transport_extract_subject (const char *filename,
-                                          const char *passphrase);
+_mongoc_secure_transport_extract_subject (const char *filename, const char *passphrase);
 
 OSStatus
-mongoc_secure_transport_write (SSLConnectionRef connection,
-                               const void *data,
-                               size_t *data_length);
+mongoc_secure_transport_write (SSLConnectionRef connection, const void *data, size_t *data_length);
 OSStatus
-mongoc_secure_transport_read (SSLConnectionRef connection,
-                              void *data,
-                              size_t *data_length);
+mongoc_secure_transport_read (SSLConnectionRef connection, void *data, size_t *data_length);
 
 bool
-mongoc_secure_transport_setup_ca (
-   mongoc_stream_tls_secure_transport_t *secure_transport,
-   mongoc_ssl_opt_t *opt);
+mongoc_secure_transport_setup_ca (mongoc_stream_tls_secure_transport_t *secure_transport, mongoc_ssl_opt_t *opt);
 
 bool
-mongoc_secure_transport_setup_certificate (
-   mongoc_stream_tls_secure_transport_t *secure_transport,
-   mongoc_ssl_opt_t *opt);
+mongoc_secure_transport_setup_certificate (mongoc_stream_tls_secure_transport_t *secure_transport,
+                                           mongoc_ssl_opt_t *opt);
+
+void
+CFReleaseSafe (CFTypeRef cf);
 
 BSON_END_DECLS
 
