@@ -14,18 +14,22 @@
  * limitations under the License.
  */
 
-#include "common-thread-private.h"
-#include "mongoc-server-monitor-private.h"
+#include <common-thread-private.h>
+#include <mongoc/mongoc-server-monitor-private.h>
 
-#include "mongoc/mcd-rpc.h"
-#include "mongoc/mongoc-client-private.h"
-#include "mongoc/mongoc-error-private.h"
-#include "mongoc/mongoc-handshake-private.h"
-#include "mongoc/mongoc-ssl-private.h"
-#include "mongoc/mongoc-stream-private.h"
-#include "mongoc/mongoc-topology-background-monitoring-private.h"
-#include "mongoc/mongoc-topology-private.h"
-#include "mongoc/mongoc-trace-private.h"
+#include <mongoc/mcd-rpc.h>
+#include <mongoc/mongoc-client-private.h>
+#include <mongoc/mongoc-error-private.h>
+#include <mongoc/mongoc-handshake-private.h>
+#include <mongoc/mongoc-ssl-private.h>
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-topology-background-monitoring-private.h>
+#include <mongoc/mongoc-topology-private.h>
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-structured-log-private.h>
+#include <common-atomic-private.h>
+
+#include <inttypes.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "monitor"
@@ -80,8 +84,6 @@ struct _mongoc_server_monitor_t {
    mongoc_stream_initiator_t initiator;
    void *initiator_context;
    int32_t request_id;
-   mongoc_apm_callbacks_t apm_callbacks;
-   void *apm_context;
 
    mongoc_stream_t *stream;
    bool more_to_come;
@@ -128,19 +130,37 @@ static void
 _server_monitor_heartbeat_started (mongoc_server_monitor_t *server_monitor, bool awaited)
 {
    mongoc_apm_server_heartbeat_started_t event;
-   MONGOC_DEBUG_ASSERT (!mcommon_mutex_is_locked (&server_monitor->topology->apm_mutex));
+   mongoc_log_and_monitor_instance_t *log_and_monitor = &server_monitor->topology->log_and_monitor;
 
-   if (!server_monitor->apm_callbacks.server_heartbeat_started) {
+   {
+      mc_shared_tpld td = mc_tpld_take_ref (BSON_ASSERT_PTR_INLINE (server_monitor)->topology);
+      bson_oid_t topology_id;
+      bson_oid_copy (&td.ptr->topology_id, &topology_id);
+      mc_tpld_drop_ref (&td);
+
+      mongoc_structured_log (
+         log_and_monitor->structured_log,
+         MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+         MONGOC_STRUCTURED_LOG_COMPONENT_TOPOLOGY,
+         "Server heartbeat started",
+         oid ("topologyId", &topology_id),
+         server_description (server_monitor->description, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID),
+         boolean ("awaited", awaited));
+   }
+
+   MONGOC_DEBUG_ASSERT (!mcommon_mutex_is_locked (&log_and_monitor->apm_mutex));
+
+   if (!log_and_monitor->apm_callbacks.server_heartbeat_started) {
       return;
    }
 
    event.host = &server_monitor->description->host;
-   event.context = server_monitor->apm_context;
+   event.context = log_and_monitor->apm_context;
    MONITOR_LOG (server_monitor, "%s heartbeat started", awaited ? "awaitable" : "regular");
    event.awaited = awaited;
-   bson_mutex_lock (&server_monitor->topology->apm_mutex);
-   server_monitor->apm_callbacks.server_heartbeat_started (&event);
-   bson_mutex_unlock (&server_monitor->topology->apm_mutex);
+   bson_mutex_lock (&log_and_monitor->apm_mutex);
+   log_and_monitor->apm_callbacks.server_heartbeat_started (&event);
+   bson_mutex_unlock (&log_and_monitor->apm_mutex);
 }
 
 static void
@@ -150,20 +170,39 @@ _server_monitor_heartbeat_succeeded (mongoc_server_monitor_t *server_monitor,
                                      bool awaited)
 {
    mongoc_apm_server_heartbeat_succeeded_t event;
+   mongoc_log_and_monitor_instance_t *log_and_monitor = &server_monitor->topology->log_and_monitor;
 
-   if (!server_monitor->apm_callbacks.server_heartbeat_succeeded) {
+   {
+      mc_shared_tpld td = mc_tpld_take_ref (BSON_ASSERT_PTR_INLINE (server_monitor)->topology);
+      bson_oid_t topology_id;
+      bson_oid_copy (&td.ptr->topology_id, &topology_id);
+      mc_tpld_drop_ref (&td);
+
+      mongoc_structured_log (
+         log_and_monitor->structured_log,
+         MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+         MONGOC_STRUCTURED_LOG_COMPONENT_TOPOLOGY,
+         "Server heartbeat succeeded",
+         oid ("topologyId", &topology_id),
+         server_description (server_monitor->description, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID),
+         boolean ("awaited", awaited),
+         monotonic_time_duration (duration_usec),
+         bson_as_json ("reply", reply));
+   }
+
+   if (!log_and_monitor->apm_callbacks.server_heartbeat_succeeded) {
       return;
    }
 
    event.host = &server_monitor->description->host;
-   event.context = server_monitor->apm_context;
+   event.context = log_and_monitor->apm_context;
    event.reply = reply;
    event.duration_usec = duration_usec;
    MONITOR_LOG (server_monitor, "%s heartbeat succeeded", awaited ? "awaitable" : "regular");
    event.awaited = awaited;
-   bson_mutex_lock (&server_monitor->topology->apm_mutex);
-   server_monitor->apm_callbacks.server_heartbeat_succeeded (&event);
-   bson_mutex_unlock (&server_monitor->topology->apm_mutex);
+   bson_mutex_lock (&log_and_monitor->apm_mutex);
+   log_and_monitor->apm_callbacks.server_heartbeat_succeeded (&event);
+   bson_mutex_unlock (&log_and_monitor->apm_mutex);
 }
 
 static void
@@ -173,20 +212,39 @@ _server_monitor_heartbeat_failed (mongoc_server_monitor_t *server_monitor,
                                   bool awaited)
 {
    mongoc_apm_server_heartbeat_failed_t event;
+   mongoc_log_and_monitor_instance_t *log_and_monitor = &server_monitor->topology->log_and_monitor;
 
-   if (!server_monitor->apm_callbacks.server_heartbeat_failed) {
+   {
+      mc_shared_tpld td = mc_tpld_take_ref (BSON_ASSERT_PTR_INLINE (server_monitor)->topology);
+      bson_oid_t topology_id;
+      bson_oid_copy (&td.ptr->topology_id, &topology_id);
+      mc_tpld_drop_ref (&td);
+
+      mongoc_structured_log (
+         log_and_monitor->structured_log,
+         MONGOC_STRUCTURED_LOG_LEVEL_DEBUG,
+         MONGOC_STRUCTURED_LOG_COMPONENT_TOPOLOGY,
+         "Server heartbeat failed",
+         oid ("topologyId", &topology_id),
+         server_description (server_monitor->description, SERVER_HOST, SERVER_PORT, SERVER_CONNECTION_ID),
+         boolean ("awaited", awaited),
+         monotonic_time_duration (duration_usec),
+         error ("failure", error));
+   }
+
+   if (!log_and_monitor->apm_callbacks.server_heartbeat_failed) {
       return;
    }
 
    event.host = &server_monitor->description->host;
-   event.context = server_monitor->apm_context;
+   event.context = log_and_monitor->apm_context;
    event.error = error;
    event.duration_usec = duration_usec;
    MONITOR_LOG (server_monitor, "%s heartbeat failed", awaited ? "awaitable" : "regular");
    event.awaited = awaited;
-   bson_mutex_lock (&server_monitor->topology->apm_mutex);
-   server_monitor->apm_callbacks.server_heartbeat_failed (&event);
-   bson_mutex_unlock (&server_monitor->topology->apm_mutex);
+   bson_mutex_lock (&log_and_monitor->apm_mutex);
+   log_and_monitor->apm_callbacks.server_heartbeat_failed (&event);
+   bson_mutex_unlock (&log_and_monitor->apm_mutex);
 }
 
 static void
@@ -541,7 +599,7 @@ _server_monitor_poll_with_interrupt (mongoc_server_monitor_t *server_monitor,
       ssize_t ret;
       mongoc_stream_poll_t poller[1];
 
-      MONITOR_LOG (server_monitor, "_server_monitor_poll_with_interrupt expires in: %" PRIu64 "ms", timeleft_ms);
+      MONITOR_LOG (server_monitor, "_server_monitor_poll_with_interrupt expires in: %" PRId64 "ms", timeleft_ms);
       poller[0].stream = server_monitor->stream;
       poller[0].events = POLLIN; /* POLLERR and POLLHUP are added in mongoc_socket_poll. */
       poller[0].revents = 0;
@@ -772,7 +830,7 @@ _update_topology_description (mongoc_server_monitor_t *server_monitor, mongoc_se
       _mongoc_topology_update_cluster_time (topology, hello_response);
    }
 
-   if (bson_atomic_int_fetch (&topology->scanner_state, bson_memory_order_relaxed) ==
+   if (mcommon_atomic_int_fetch (&topology->scanner_state, mcommon_memory_order_relaxed) ==
        MONGOC_TOPOLOGY_SCANNER_SHUTTING_DOWN) {
       return;
    }
@@ -781,8 +839,12 @@ _update_topology_description (mongoc_server_monitor_t *server_monitor, mongoc_se
    bson_mutex_lock (&server_monitor->shared.mutex);
    server_monitor->shared.scan_requested = false;
    bson_mutex_unlock (&server_monitor->shared.mutex);
-   mongoc_topology_description_handle_hello (
-      tdmod.new_td, server_monitor->server_id, hello_response, description->round_trip_time_msec, &description->error);
+   mongoc_topology_description_handle_hello (tdmod.new_td,
+                                             &topology->log_and_monitor,
+                                             server_monitor->server_id,
+                                             hello_response,
+                                             description->round_trip_time_msec,
+                                             &description->error);
    /* Reconcile server monitors. */
    _mongoc_topology_background_monitoring_reconcile (topology, tdmod.new_td);
    /* Wake threads performing server selection. */
@@ -835,8 +897,6 @@ mongoc_server_monitor_new (mongoc_topology_t *topology,
       _mongoc_ssl_opts_copy_to (topology->scanner->ssl_opts, server_monitor->ssl_opts, true);
    }
 #endif
-   memcpy (&server_monitor->apm_callbacks, &td->apm_callbacks, sizeof (mongoc_apm_callbacks_t));
-   server_monitor->apm_context = td->apm_context;
    server_monitor->initiator = topology->scanner->initiator;
    server_monitor->initiator_context = topology->scanner->initiator_context;
    server_monitor->mode = _server_monitor_get_mode_enum (server_monitor);
