@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-config.h"
+#include <mongoc/mongoc-config.h>
 
 #ifdef MONGOC_ENABLE_SSL_SECURE_TRANSPORT
 
@@ -25,16 +25,18 @@
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-trace-private.h"
-#include "mongoc/mongoc-log.h"
-#include "mongoc/mongoc-secure-transport-private.h"
-#include "mongoc/mongoc-ssl.h"
-#include "mongoc/mongoc-error.h"
-#include "mongoc/mongoc-counters-private.h"
-#include "mongoc/mongoc-stream-tls.h"
-#include "mongoc/mongoc-stream-tls-private.h"
-#include "mongoc/mongoc-stream-private.h"
-#include "mongoc/mongoc-stream-tls-secure-transport-private.h"
+#include <mongoc/mongoc-trace-private.h>
+#include <mongoc/mongoc-log.h>
+#include <mongoc/mongoc-secure-transport-private.h>
+#include <mongoc/mongoc-ssl.h>
+#include <mongoc/mongoc-ssl-private.h>
+#include <mongoc/mongoc-error.h>
+#include <mongoc/mongoc-counters-private.h>
+#include <mongoc/mongoc-stream-tls.h>
+#include <mongoc/mongoc-stream-tls-private.h>
+#include <mongoc/mongoc-stream-private.h>
+#include <mongoc/mongoc-stream-tls-secure-transport-private.h>
+#include <common-string-private.h>
 
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "stream-tls-secure_transport"
@@ -43,8 +45,7 @@ static void
 _mongoc_stream_tls_secure_transport_destroy (mongoc_stream_t *stream)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
@@ -83,8 +84,7 @@ _mongoc_stream_tls_secure_transport_close (mongoc_stream_t *stream)
 {
    int ret = 0;
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
@@ -97,8 +97,7 @@ static int
 _mongoc_stream_tls_secure_transport_flush (mongoc_stream_t *stream)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
@@ -106,14 +105,11 @@ _mongoc_stream_tls_secure_transport_flush (mongoc_stream_t *stream)
 }
 
 static ssize_t
-_mongoc_stream_tls_secure_transport_write (mongoc_stream_t *stream,
-                                           char *buf,
-                                           size_t buf_len)
+_mongoc_stream_tls_secure_transport_write (mongoc_stream_t *stream, char *buf, size_t buf_len)
 {
    OSStatus status;
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
    ssize_t write_ret;
    int64_t now;
    int64_t expire = 0;
@@ -125,8 +121,7 @@ _mongoc_stream_tls_secure_transport_write (mongoc_stream_t *stream,
       expire = bson_get_monotonic_time () + (tls->timeout_msec * 1000UL);
    }
 
-   status = SSLWrite (
-      secure_transport->ssl_ctx_ref, buf, buf_len, (size_t *) &write_ret);
+   status = SSLWrite (secure_transport->ssl_ctx_ref, buf, buf_len, (size_t *) &write_ret);
 
    switch (status) {
    case errSSLWouldBlock:
@@ -166,8 +161,7 @@ _mongoc_stream_tls_secure_transport_writev (mongoc_stream_t *stream,
                                             int32_t timeout_msec)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
    char buf[MONGOC_STREAM_TLS_BUFFER_SIZE];
    ssize_t ret = 0;
    ssize_t child_ret;
@@ -203,9 +197,7 @@ _mongoc_stream_tls_secure_transport_writev (mongoc_stream_t *stream,
       iov_pos = 0;
 
       while (iov_pos < iov[i].iov_len) {
-         if (buf_head != buf_tail ||
-             ((i + 1 < iovcnt) &&
-              ((buf_end - buf_tail) > (iov[i].iov_len - iov_pos)))) {
+         if (buf_head != buf_tail || ((i + 1 < iovcnt) && ((buf_end - buf_tail) > (iov[i].iov_len - iov_pos)))) {
             /* If we have either of:
              *   - buffered bytes already
              *   - another iovec to send after this one and we don't have more
@@ -240,8 +232,7 @@ _mongoc_stream_tls_secure_transport_writev (mongoc_stream_t *stream,
             /* We get here if we buffered some bytes and filled the buffer, or
              * if we didn't buffer and have to send out of the iovec */
 
-            child_ret = _mongoc_stream_tls_secure_transport_write (
-               stream, to_write, to_write_len);
+            child_ret = _mongoc_stream_tls_secure_transport_write (stream, to_write, to_write_len);
 
             if (child_ret < 0) {
                RETURN (ret);
@@ -263,8 +254,7 @@ _mongoc_stream_tls_secure_transport_writev (mongoc_stream_t *stream,
    if (buf_head != buf_tail) {
       /* If we have any bytes buffered, send */
 
-      child_ret = _mongoc_stream_tls_secure_transport_write (
-         stream, buf_head, buf_tail - buf_head);
+      child_ret = _mongoc_stream_tls_secure_transport_write (stream, buf_head, buf_tail - buf_head);
 
       if (child_ret < 0) {
          RETURN (child_ret);
@@ -283,21 +273,20 @@ _mongoc_stream_tls_secure_transport_writev (mongoc_stream_t *stream,
 
 /* This function is copypasta of _mongoc_stream_tls_openssl_readv */
 static ssize_t
-_mongoc_stream_tls_secure_transport_readv (mongoc_stream_t *stream,
-                                           mongoc_iovec_t *iov,
-                                           size_t iovcnt,
-                                           size_t min_bytes,
-                                           int32_t timeout_msec)
+_mongoc_stream_tls_secure_transport_readv (
+   mongoc_stream_t *stream, mongoc_iovec_t *iov, size_t iovcnt, size_t min_bytes, int32_t timeout_msec)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
    ssize_t ret = 0;
    size_t i;
    size_t read_ret;
    size_t iov_pos = 0;
    int64_t now;
    int64_t expire = 0;
+   size_t to_read;
+   size_t remaining_buf_size;
+   size_t remaining_to_read;
 
    BSON_ASSERT (iov);
    BSON_ASSERT (iovcnt);
@@ -314,10 +303,21 @@ _mongoc_stream_tls_secure_transport_readv (mongoc_stream_t *stream,
       iov_pos = 0;
 
       while (iov_pos < iov[i].iov_len) {
-         OSStatus status = SSLRead (secure_transport->ssl_ctx_ref,
-                                    (char *) iov[i].iov_base + iov_pos,
-                                    (int) (iov[i].iov_len - iov_pos),
-                                    &read_ret);
+         remaining_buf_size = iov[i].iov_len - iov_pos;
+         remaining_to_read = min_bytes - ret;
+
+         /* The third argument passed to SSLRead is an all-or-nothing
+            dataLength, which it will attempt to read until it succeeds or
+            times out. If our buffer is larger than the message we expect
+            to read, choose the smaller number of the two. */
+         if (remaining_to_read > 0 && remaining_to_read < remaining_buf_size) {
+            to_read = remaining_to_read;
+         } else {
+            to_read = remaining_buf_size;
+         }
+
+         OSStatus status =
+            SSLRead (secure_transport->ssl_ctx_ref, (char *) iov[i].iov_base + iov_pos, to_read, &read_ret);
 
          if (status != noErr) {
             RETURN (-1);
@@ -358,28 +358,22 @@ _mongoc_stream_tls_secure_transport_readv (mongoc_stream_t *stream,
 }
 
 static int
-_mongoc_stream_tls_secure_transport_setsockopt (mongoc_stream_t *stream,
-                                                int level,
-                                                int optname,
-                                                void *optval,
-                                                mongoc_socklen_t optlen)
+_mongoc_stream_tls_secure_transport_setsockopt (
+   mongoc_stream_t *stream, int level, int optname, void *optval, mongoc_socklen_t optlen)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
-   RETURN (mongoc_stream_setsockopt (
-      tls->base_stream, level, optname, optval, optlen));
+   RETURN (mongoc_stream_setsockopt (tls->base_stream, level, optname, optval, optlen));
 }
 
 static mongoc_stream_t *
 _mongoc_stream_tls_secure_transport_get_base_stream (mongoc_stream_t *stream)
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
@@ -388,18 +382,176 @@ _mongoc_stream_tls_secure_transport_get_base_stream (mongoc_stream_t *stream)
 
 
 static bool
-_mongoc_stream_tls_secure_transport_check_closed (
-   mongoc_stream_t *stream) /* IN */
+_mongoc_stream_tls_secure_transport_check_closed (mongoc_stream_t *stream) /* IN */
 {
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
    RETURN (mongoc_stream_check_closed (tls->base_stream));
 }
 
+static void
+_set_error_from_osstatus (OSStatus status, const char *prefix, bson_error_t *error)
+{
+   CFStringRef err;
+   char *err_str;
+
+   err = SecCopyErrorMessageString (status, NULL);
+   err_str = _mongoc_cfstringref_to_cstring (err);
+   bson_set_error (error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_SOCKET, "%s: %s (%d)", prefix, err_str, status);
+
+   bson_free (err_str);
+   CFRelease (err);
+}
+
+/* Always returns a string that must be freed. */
+static char *
+explain_trust_result (SecTrustRef trust, SecTrustResultType trust_result)
+{
+   CFArrayRef cfprops = NULL;
+   CFIndex count, i;
+
+   mcommon_string_append_t reason;
+   mcommon_string_new_as_append (&reason);
+
+   switch (trust_result) {
+   case kSecTrustResultDeny:
+      mcommon_string_append (&reason, "Certificate trust denied");
+      break;
+   case kSecTrustResultRecoverableTrustFailure:
+      mcommon_string_append (&reason, "Certificate trust failure");
+      break;
+   case kSecTrustResultFatalTrustFailure:
+      mcommon_string_append (&reason, "Certificate trust fatal failure");
+      break;
+   case kSecTrustResultInvalid:
+      mcommon_string_append (&reason, "Certificate trust evaluation failure");
+      break;
+   default:
+      mcommon_string_append_printf (&reason, "Certificate trust failure #%d", (int) trust_result);
+      break;
+   }
+   mcommon_string_append (&reason, ": ");
+
+   cfprops = SecTrustCopyProperties (trust);
+   /* This contains an array of dictionaries, each representing a cert in the
+    * chain. Append the first failure reason found. */
+   if (!cfprops) {
+      mcommon_string_append (&reason, "Unable to retreive cause for trust failure");
+      goto done;
+   }
+
+   count = CFArrayGetCount (cfprops);
+   for (i = 0; i < count; ++i) {
+      const void *elem = NULL;
+      const void *reason_elem = NULL;
+      char *reason_str;
+      CFDictionaryRef dict;
+
+      elem = CFArrayGetValueAtIndex (cfprops, i);
+      if (CFGetTypeID (elem) != CFDictionaryGetTypeID ()) {
+         mcommon_string_append (&reason, "Unable to parse cause for trust failure");
+         goto done;
+      }
+
+      dict = (CFDictionaryRef) elem;
+      reason_elem = CFDictionaryGetValue (dict, kSecPropertyTypeError);
+      if (!reason_elem) {
+         continue;
+      }
+      if (CFGetTypeID (reason_elem) != CFStringGetTypeID ()) {
+         mcommon_string_append (&reason, "Unable to parse trust failure error");
+         goto done;
+      }
+      reason_str = _mongoc_cfstringref_to_cstring (reason_elem);
+      if (reason_str) {
+         mcommon_string_append (&reason, reason_str);
+         bson_free (reason_str);
+         goto done;
+      } else {
+         mcommon_string_append (&reason, "Unable to express trust failure error");
+         goto done;
+      }
+   }
+
+   mcommon_string_append (&reason, "No trust failure reason available");
+done:
+   CFReleaseSafe (cfprops);
+   return mcommon_string_from_append_destroy_with_steal (&reason);
+}
+
+/* Returns a boolean indicating success. If false is returned, then an error is
+ * set.
+ */
+static bool
+_verify_peer (mongoc_stream_t *stream, bson_error_t *error)
+{
+   CFArrayRef policies = NULL;
+   SecTrustRef trust = NULL;
+   OSStatus status;
+   CFMutableArrayRef policies_mutable = NULL;
+   SecPolicyRef rev_policy = NULL;
+   SecTrustResultType trust_result;
+   mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   bool ret = false;
+
+   status = SSLCopyPeerTrust (secure_transport->ssl_ctx_ref, &trust);
+   if (status != noErr) {
+      _set_error_from_osstatus (status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   status = SecTrustCopyPolicies (trust, &policies);
+
+   if (status != noErr) {
+      _set_error_from_osstatus (status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   /* Add explicit OCSP revocation policy. */
+   policies_mutable = CFArrayCreateMutableCopy (NULL, 0, policies);
+
+   /* TODO: possibly disable endpoint checking by adding the flag
+    * kSecRevocationNetworkAccessDisabled once the option
+    * tlsDisableOCSPEndpointCheck is implemented. */
+   rev_policy = SecPolicyCreateRevocation (kSecRevocationOCSPMethod);
+   CFArrayAppendValue (policies_mutable, rev_policy);
+
+   status = SecTrustSetPolicies (trust, policies_mutable);
+
+   if (status != noErr) {
+      _set_error_from_osstatus (status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   /* TODO: SecTrustEvaluate is blocking. When making Secure Transport's
+    * handshake is made non-blocking in CDRIVER-2885, this will need to be
+    * addressed. */
+   status = SecTrustEvaluate (trust, &trust_result);
+   if (status != noErr) {
+      _set_error_from_osstatus (status, "Certificate validation errored", error);
+      goto fail;
+   }
+
+   if (trust_result != kSecTrustResultProceed && trust_result != kSecTrustResultUnspecified) {
+      char *reason = explain_trust_result (trust, trust_result);
+      bson_set_error (error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_SOCKET, "TLS handshake failed (%s)", reason);
+      bson_free (reason);
+      goto fail;
+   }
+
+   ret = true;
+fail:
+   CFReleaseSafe (trust);
+   CFReleaseSafe (policies);
+   CFReleaseSafe (policies_mutable);
+   CFReleaseSafe (rev_policy);
+   return ret;
+}
+
 bool
 mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
                                               const char *host,
@@ -407,19 +559,19 @@ mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
                                               bson_error_t *error)
 {
    OSStatus ret = 0;
-   CFStringRef err;
-   char *err_str;
    mongoc_stream_tls_t *tls = (mongoc_stream_tls_t *) stream;
-   mongoc_stream_tls_secure_transport_t *secure_transport =
-      (mongoc_stream_tls_secure_transport_t *) tls->ctx;
+   mongoc_stream_tls_secure_transport_t *secure_transport = (mongoc_stream_tls_secure_transport_t *) tls->ctx;
 
    ENTRY;
    BSON_ASSERT (secure_transport);
 
    ret = SSLHandshake (secure_transport->ssl_ctx_ref);
-   /* Weak certificate validation requested, eg: none */
 
    if (ret == errSSLServerAuthCompleted) {
+      if (!tls->ssl_opts.weak_cert_validation && !_verify_peer (stream, error)) {
+         *events = 0;
+         RETURN (false);
+      }
       ret = errSSLWouldBlock;
    }
 
@@ -431,17 +583,7 @@ mongoc_stream_tls_secure_transport_handshake (mongoc_stream_t *stream,
       *events = POLLIN | POLLOUT;
    } else {
       *events = 0;
-      err = SecCopyErrorMessageString (ret, NULL);
-      err_str = _mongoc_cfstringref_to_cstring (err);
-      bson_set_error (error,
-                      MONGOC_ERROR_STREAM,
-                      MONGOC_ERROR_STREAM_SOCKET,
-                      "TLS handshake failed: %s (%d)",
-                      err_str,
-                      ret);
-
-      bson_free (err_str);
-      CFRelease (err);
+      _set_error_from_osstatus (ret, "TLS handshake failed", error);
    }
 
    RETURN (false);
@@ -486,14 +628,12 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
       RETURN (NULL);
    }
    if (opt->crl_file) {
-      MONGOC_ERROR (
-         "Setting mongoc_ssl_opt_t.crl_file has no effect when built "
-         "against Secure Transport");
+      MONGOC_ERROR ("Setting mongoc_ssl_opt_t.crl_file has no effect when built "
+                    "against Secure Transport");
       RETURN (NULL);
    }
 
-   secure_transport = (mongoc_stream_tls_secure_transport_t *) bson_malloc0 (
-      sizeof *secure_transport);
+   secure_transport = (mongoc_stream_tls_secure_transport_t *) bson_malloc0 (sizeof *secure_transport);
 
    tls = (mongoc_stream_tls_t *) bson_malloc0 (sizeof *tls);
    tls->parent.type = MONGOC_STREAM_TLS;
@@ -504,8 +644,7 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
    tls->parent.writev = _mongoc_stream_tls_secure_transport_writev;
    tls->parent.readv = _mongoc_stream_tls_secure_transport_readv;
    tls->parent.setsockopt = _mongoc_stream_tls_secure_transport_setsockopt;
-   tls->parent.get_base_stream =
-      _mongoc_stream_tls_secure_transport_get_base_stream;
+   tls->parent.get_base_stream = _mongoc_stream_tls_secure_transport_get_base_stream;
    tls->parent.check_closed = _mongoc_stream_tls_secure_transport_check_closed;
    tls->parent.timed_out = _mongoc_stream_tls_secure_channel_timed_out;
    tls->parent.should_retry = _mongoc_stream_tls_secure_channel_should_retry;
@@ -515,23 +654,17 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
    tls->timeout_msec = -1;
 
    secure_transport->ssl_ctx_ref =
-      SSLCreateContext (kCFAllocatorDefault,
-                        client ? kSSLClientSide : kSSLServerSide,
-                        kSSLStreamType);
+      SSLCreateContext (kCFAllocatorDefault, client ? kSSLClientSide : kSSLServerSide, kSSLStreamType);
 
-   SSLSetIOFuncs (secure_transport->ssl_ctx_ref,
-                  mongoc_secure_transport_read,
-                  mongoc_secure_transport_write);
+   SSLSetIOFuncs (secure_transport->ssl_ctx_ref, mongoc_secure_transport_read, mongoc_secure_transport_write);
    SSLSetProtocolVersionMin (secure_transport->ssl_ctx_ref, kTLSProtocol1);
 
-   if (opt->pem_file &&
-       !mongoc_secure_transport_setup_certificate (secure_transport, opt)) {
+   if (opt->pem_file && !mongoc_secure_transport_setup_certificate (secure_transport, opt)) {
       mongoc_stream_destroy ((mongoc_stream_t *) tls);
       RETURN (NULL);
    }
 
-   if (opt->ca_file &&
-       !mongoc_secure_transport_setup_ca (secure_transport, opt)) {
+   if (opt->ca_file && !mongoc_secure_transport_setup_ca (secure_transport, opt)) {
       mongoc_stream_destroy ((mongoc_stream_t *) tls);
       RETURN (NULL);
    }
@@ -540,13 +673,12 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
    tls->base_stream = base_stream;
 
    if (client) {
-      SSLSetSessionOption (secure_transport->ssl_ctx_ref,
-                           kSSLSessionOptionBreakOnServerAuth,
-                           opt->weak_cert_validation);
+      /* This option has SSL_Handshake stop before it verifies peer cert. Set
+       * this since we verify peer cert manually later. */
+      SSLSetSessionOption (secure_transport->ssl_ctx_ref, kSSLSessionOptionBreakOnServerAuth, true);
    } else if (!opt->allow_invalid_hostname) {
       /* used only in mock_server_t tests */
-      SSLSetClientSideAuthenticate (secure_transport->ssl_ctx_ref,
-                                    kAlwaysAuthenticate);
+      SSLSetClientSideAuthenticate (secure_transport->ssl_ctx_ref, kAlwaysAuthenticate);
    }
 
    if (!opt->allow_invalid_hostname) {
@@ -556,6 +688,16 @@ mongoc_stream_tls_secure_transport_new (mongoc_stream_t *base_stream,
 
 
    mongoc_counter_streams_active_inc ();
+
+   if (_mongoc_ssl_opts_disable_certificate_revocation_check (opt)) {
+      MONGOC_ERROR ("Setting tlsDisableCertificateRevocationCheck has no "
+                    "effect when built against Secure Transport");
+   }
+
+   if (_mongoc_ssl_opts_disable_ocsp_endpoint_check (opt)) {
+      MONGOC_ERROR ("Setting tlsDisableOCSPEndpointCheck has no effect when "
+                    "built against Secure Transport");
+   }
    RETURN ((mongoc_stream_t *) tls);
 }
 #endif /* MONGOC_ENABLE_SSL_SECURE_TRANSPORT */
