@@ -14,13 +14,13 @@
  * limitations under the License.
  */
 
-#include "mongoc-prelude.h"
+#include <mongoc/mongoc-prelude.h>
 
 #ifndef MONGOC_UTIL_PRIVATE_H
 #define MONGOC_UTIL_PRIVATE_H
 
 #include <bson/bson.h>
-#include "mongoc.h"
+#include <mongoc/mongoc.h>
 
 #ifdef BSON_HAVE_STRINGS_H
 #include <strings.h>
@@ -34,19 +34,6 @@
 #define strncasecmp _strnicmp
 #endif
 
-#if BSON_GNUC_CHECK_VERSION(4, 6)
-#define BEGIN_IGNORE_DEPRECATIONS \
-   _Pragma ("GCC diagnostic push") _Pragma ("GCC diagnostic ignored \"-Wdeprecated-declarations\"")
-#define END_IGNORE_DEPRECATIONS _Pragma ("GCC diagnostic pop")
-#elif defined(__clang__)
-#define BEGIN_IGNORE_DEPRECATIONS \
-   _Pragma ("clang diagnostic push") _Pragma ("clang diagnostic ignored \"-Wdeprecated-declarations\"")
-#define END_IGNORE_DEPRECATIONS _Pragma ("clang diagnostic pop")
-#else
-#define BEGIN_IGNORE_DEPRECATIONS
-#define END_IGNORE_DEPRECATIONS
-#endif
-
 #ifndef _WIN32
 #define MONGOC_PRINTF_FORMAT(a, b) __attribute__ ((format (__printf__, a, b)))
 #else
@@ -258,6 +245,11 @@ hex_to_bin (const char *hex, uint32_t *len);
 char *
 bin_to_hex (const uint8_t *bin, uint32_t len);
 
+typedef struct {
+   bool set;
+   uint64_t value;
+} mcd_optional_u64_t;
+
 BSON_END_DECLS
 
 #endif /* MONGOC_UTIL_PRIVATE_H */
