@@ -373,6 +373,7 @@ extern zend_class_entry* php_phongo_commandfailedevent_ce;
 extern zend_class_entry* php_phongo_commandstartedevent_ce;
 extern zend_class_entry* php_phongo_commandsubscriber_ce;
 extern zend_class_entry* php_phongo_commandsucceededevent_ce;
+extern zend_class_entry* php_phongo_logsubscriber_ce;
 extern zend_class_entry* php_phongo_sdamsubscriber_ce;
 extern zend_class_entry* php_phongo_subscriber_ce;
 extern zend_class_entry* php_phongo_serverchangedevent_ce;
@@ -457,6 +458,7 @@ extern void php_phongo_commandfailedevent_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_commandstartedevent_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_commandsubscriber_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_commandsucceededevent_init_ce(INIT_FUNC_ARGS);
+extern void php_phongo_logsubscriber_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_sdamsubscriber_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_subscriber_init_ce(INIT_FUNC_ARGS);
 extern void php_phongo_serverchangedevent_init_ce(INIT_FUNC_ARGS);
