@@ -5,6 +5,7 @@ use MongoDB\Driver\Command;
 use MongoDB\Driver\Manager;
 use MongoDB\Driver\ReadPreference;
 use MongoDB\Driver\Server;
+use MongoDB\Driver\ServerApi;
 use MongoDB\Driver\WriteConcern;
 use MongoDB\Driver\WriteConcernError;
 use MongoDB\Driver\WriteError;
@@ -50,15 +51,18 @@ function drop_collection($uri, $databaseName, $collectionName)
     $command = new Command(['drop' => $collectionName]);
 
     try {
-        /* We need to use WriteConcern::MAJORITY here due to the issue
-         * explained in SERVER-35613: "drop" uses a two phase commit, and due
-         * to that, it is possible that a lock can't be acquired for a
-         * transaction that gets quickly started as the "drop" reaper hasn't
-         * completed yet. */
+        /* Unless we are dropping a collection within the "local" database,
+         * which does not support a write concern, we need to use w:majority due
+         * to the issue explained in SERVER-35613: "drop" uses a two phase
+         * commit, and due to that, it is possible that a lock can't be acquired
+         * for a transaction that gets quickly started as the "drop" reaper
+         * hasn't completed yet. */
+        $wc = $databaseName === 'local' ? new WriteConcern(1) : new WriteConcern(WriteConcern::MAJORITY);
+
         $server->executeCommand(
             $databaseName,
             $command,
-            ['writeConcern' => new WriteConcern(WriteConcern::MAJORITY)]
+            ['writeConcern' => $wc]
         );
     } catch (RuntimeException $e) {
         if ($e->getMessage() !== 'ns not found') {
@@ -79,7 +83,7 @@ function get_module_info($row)
     phpinfo(INFO_MODULES);
     $info = ob_get_clean();
 
-    $pattern = sprintf('/^%s([\w ]+)$/m', preg_quote($row . ' => '));
+    $pattern = sprintf('/^%s(.*)$/m', preg_quote($row . ' => '));
 
     if (preg_match($pattern, $info, $matches) !== 1) {
         return null;
@@ -88,6 +92,23 @@ function get_module_info($row)
     return $matches[1];
 }
 
+function create_test_manager(?string $uri = null, array $options = [], array $driverOptions = [])
+{
+    if (getenv('API_VERSION') && ! isset($driverOptions['serverApi'])) {
+        $driverOptions['serverApi'] = new ServerApi(getenv('API_VERSION'));
+    }
+
+    if (getenv('CRYPT_SHARED_LIB_PATH') && isset($driverOptions['autoEncryption'])) {
+        if (is_array($driverOptions['autoEncryption']) &&
+            (! isset($driverOptions['autoEncryption']['extraOptions']) || is_array($driverOptions['autoEncryption']['extraOptions'])) &&
+            ! isset($driverOptions['autoEncryption']['extraOptions']['cryptSharedLibPath'])) {
+            $driverOptions['autoEncryption']['extraOptions']['cryptSharedLibPath'] = getenv('CRYPT_SHARED_LIB_PATH');
+        }
+    }
+
+    return new Manager($uri ?? URI, $options, $driverOptions);
+}
+
 /**
  * Returns the primary server.
  *
@@ -97,7 +118,7 @@ function get_module_info($row)
  */
 function get_primary_server($uri)
 {
-    return (new Manager($uri))->selectServer(new ReadPreference('primary'));
+    return create_test_manager($uri)->selectServer(new ReadPreference('primary'));
 }
 
 /**
@@ -109,7 +130,7 @@ function get_primary_server($uri)
  */
 function get_secondary_server($uri)
 {
-    return (new Manager($uri))->selectServer(new ReadPreference('secondary'));
+    return create_test_manager($uri)->selectServer(new ReadPreference('secondary'));
 }
 
 /**
@@ -209,6 +230,17 @@ function get_uri_option($uri, $option)
     return $matches[1];
 }
 
+/**
+ * Checks that the topology is load balanced.
+ *
+ * @param string $uri
+ * @return boolean
+ */
+function is_load_balanced($uri)
+{
+    return get_primary_server($uri)->getType() === Server::TYPE_LOAD_BALANCER;
+}
+
 /**
  * Checks that the topology is a sharded cluster.
  *
@@ -221,19 +253,19 @@ function is_mongos($uri)
 }
 
 /**
- * Checks that the topology is a sharded cluster using a replica set
+ * Checks that the topology is a sharded cluster using a replica set.
+ *
+ * Note: only the first shard is checked.
  */
-function is_mongos_with_replica_set($uri)
+function is_sharded_cluster_with_replica_set($uri)
 {
-    if (! is_mongos($uri)) {
+    $server = get_primary_server($uri);
+
+    if ($server->getType() !== Server::TYPE_MONGOS && $server->getType() !== Server::TYPE_LOAD_BALANCER) {
         return false;
     }
 
-    $cursor = get_primary_server($uri)->executeQuery(
-        'config.shards',
-        new \MongoDB\Driver\Query([], ['limit' => 1])
-    );
-
+    $cursor = $server->executeQuery('config.shards', new \MongoDB\Driver\Query([], ['limit' => 1]));
     $cursor->setTypeMap(['root' => 'array', 'document' => 'array']);
     $document = current($cursor->toArray());
 
@@ -261,6 +293,8 @@ function is_replica_set($uri)
         return false;
     }
 
+    /* Note: this may return a false negative if replicaSet is specified through
+     * a TXT record for a mongodb+srv connection string. */
     if (get_uri_option($uri, 'replicaSet') === NULL) {
         return false;
     }
@@ -419,11 +453,20 @@ function json_canonicalize($json)
 {
     $json = json_encode(json_decode($json));
 
-    /* Versions of PHP before 7.1 replace empty JSON keys with "_empty_" when
-     * decoding to a stdClass (see: https://bugs.php.net/bug.php?id=46600). Work
-     * around this by replacing "_empty_" keys before returning.
-     */
-    return str_replace('"_empty_":', '"":', $json);
+    /* Canonicalize string values for $numberDouble to ensure they are converted
+     * the same as number literals in legacy and relaxed output. This is needed
+     * because the printf format in _bson_as_json_visit_double uses a high level
+     * of precision and may not produce the exponent notation expected by the
+     * BSON corpus tests. */
+    $json = preg_replace_callback(
+        '/{"\$numberDouble":"(-?\d+(\.\d+([eE]\+\d+)?)?)"}/',
+        function ($matches) {
+            return '{"$numberDouble":"' . json_encode(json_decode($matches[1])) . '"}';
+        },
+        $json
+    );
+
+    return $json;
 }
 
 /**
@@ -474,7 +517,7 @@ function loadFixtures(Manager $manager, $dbname = DATABASE_NAME, $collname = COL
 
     $bulk = new BulkWrite(['ordered' => false]);
 
-    $server = $manager->selectServer(new ReadPreference(ReadPreference::RP_PRIMARY));
+    $server = $manager->selectServer(new ReadPreference(ReadPreference::PRIMARY));
 
     $data = file_get_contents($filename);
     $array = json_decode($data);
@@ -543,82 +586,120 @@ function destroyTemporaryMongoInstance($id = NULL)
     $json = file_get_contents(MONGO_ORCHESTRATION_URI . "/servers/$id", false, $ctx);
 }
 
-function severityToString($type) {
-    switch($type) {
-    case E_RECOVERABLE_ERROR:
-        return "E_RECOVERABLE_ERROR";
-    case E_WARNING:
-        return "E_WARNING";
-    case E_NOTICE:
-        return "E_NOTICE";
-    default:
-        return "Some other #_$type";
+/**
+ * Converts an error level (constant or bitmask) to a string description.
+ */
+function severityToString(int $severity): string {
+    static $constants = [
+        'E_ERROR' => E_ERROR,
+        'E_WARNING' => E_WARNING,
+        'E_PARSE' => E_PARSE,
+        'E_NOTICE' => E_NOTICE,
+        'E_CORE_ERROR' => E_CORE_ERROR,
+        'E_CORE_WARNING' => E_CORE_WARNING,
+        'E_COMPILE_ERROR' => E_COMPILE_ERROR,
+        'E_COMPILE_WARNING' => E_COMPILE_WARNING,
+        'E_USER_ERROR' => E_USER_ERROR,
+        'E_USER_WARNING' => E_USER_WARNING,
+        'E_USER_NOTICE' => E_USER_NOTICE,
+        'E_STRICT' => 2048, // E_STRICT was deprecated in PHP 8.4
+        'E_RECOVERABLE_ERROR' => E_RECOVERABLE_ERROR,
+        'E_DEPRECATED' => E_DEPRECATED,
+        'E_USER_DEPRECATED' => E_USER_DEPRECATED,
+        // E_ALL is handled separately
+    ];
+
+    if ($severity === E_ALL) {
+        return 'E_ALL';
     }
-}
-function raises($function, $type, $infunction = null) {
-    $errhandler = function($severity, $message, $file, $line, $errcontext) {
-        throw new ErrorException($message, 0, $severity, $file, $line);
-    };
 
-    set_error_handler($errhandler, $type);
-    try {
-        $function();
-    } catch(Exception $e) {
-        $exceptionname = get_class($e);
-
-        if ($e instanceof ErrorException && $e->getSeverity() & $type) {
-            if ($infunction) {
-                $trace = $e->getTrace();
-                $function = $trace[0]["function"];
-                if (strcasecmp($function, $infunction) == 0) {
-                    printf("OK: Got %s thrown from %s\n", $exceptionname, $infunction);
-                } else {
-                    printf("ALMOST: Got %s - but was thrown in %s, not %s\n", $exceptionname, $function, $infunction);
-                }
-                restore_error_handler();
-                return $e->getMessage();
-            }
-            printf("OK: Got %s\n", severityToString($type));
-        } else {
-            printf("ALMOST: Got %s - expected %s\n", get_class($e), $exceptionname);
+    foreach ($constants as $constant => $value) {
+        if ($severity & $value) {
+            $matches[] = $constant;
         }
+    }
+
+    return empty($matches) ? 'UNKNOWN' : implode('|', $matches);
+}
+
+/**
+ * Expects the callable to raise an error matching the expected severity, which
+ * may be a constant or bitmask. May optionally expect the error to be raised
+ * from a particular function. Returns the message from the raised error or
+ * exception, or an empty string if neither was thrown.
+ */
+function raises(callable $callable, int $expectedSeverity, ?string $expectedFromFunction = null): string
+{
+    set_error_handler(function(int $severity, string $message, string $file, int $line) {
+        throw new ErrorException($message, 0, $severity, $file, $line);
+    });
+
+    try {
+        call_user_func($callable);
+    } catch (ErrorException $e) {
+        if (!($e->getSeverity() & $expectedSeverity)) {
+            printf("ALMOST: Got %s - expected %s\n", severityToString($e->getSeverity()), severityToString($expectedSeverity));
+            return $e->getMessage();
+        }
+
+        if ($expectedFromFunction === null) {
+            printf("OK: Got %s\n", severityToString($e->getSeverity()));
+            return $e->getMessage();
+        }
+
+        $fromFunction = $e->getTrace()[0]['function'];
+
+        if (strcasecmp($fromFunction, $expectedFromFunction) !== 0) {
+            printf("ALMOST: Got %s - but was raised from %s, not %s\n", errorLevelToString($e->getSeverity()), $fromFunction, $expectedFromFunction);
+            return $e->getMessage();
+        }
+
+        printf("OK: Got %s raised from %s\n", severityToString($e->getSeverity()), $fromFunction);
+        return $e->getMessage();
+    } catch (Throwable $e) {
+        printf("ALMOST: Got %s - expected %s\n", get_class($e), ErrorException::class);
+        return $e->getMessage();
+    } finally {
         restore_error_handler();
+    }
+
+    printf("FAILED: Expected %s, but no error raised!\n", ErrorException::class);
+    return '';
+}
+
+/**
+ * Expects the callable to throw an expected exception. May optionally expect
+ * the exception to be thrown from a particular function. Returns the message
+ * from the thrown exception, or an empty string if one was not thrown.
+ */
+function throws(callable $callable, string $expectedException, ?string $expectedFromFunction = null): string
+{
+    try {
+        call_user_func($callable);
+    } catch (Throwable $e) {
+        if (!($e instanceof $expectedException)) {
+            printf("ALMOST: Got %s - expected %s\n", get_class($e), $expectedException);
+            return $e->getMessage();
+        }
+
+        if ($expectedFromFunction === null) {
+            printf("OK: Got %s\n", $expectedException);
+            return $e->getMessage();
+        }
+
+        $fromFunction = $e->getTrace()[0]['function'];
+
+        if (strcasecmp($fromFunction, $expectedFromFunction) !== 0) {
+            printf("ALMOST: Got %s - but was thrown from %s, not %s\n", $expectedException, $fromFunction, $expectedFromFunction);
+            return $e->getMessage();
+        }
+
+        printf("OK: Got %s thrown from %s\n", $expectedException, $fromFunction);
         return $e->getMessage();
     }
 
-    printf("FAILED: Expected %s thrown!\n", ErrorException::class);
-    restore_error_handler();
-}
-function throws($function, $exceptionname, $infunction = null) {
-    try {
-        $function();
-    } catch (Throwable $e) {
-    } catch(Exception $e) {
-    }
-
-    if ($e === null) {
-        echo "FAILED: Expected $exceptionname thrown, but no exception thrown!\n";
-        return;
-    }
-
-    $message = str_replace(array("\n", "\r"), ' ', $e->getMessage());
-    if ($e instanceof $exceptionname) {
-        if ($infunction) {
-            $trace = $e->getTrace();
-            $function = $trace[0]["function"];
-            if (strcasecmp($function, $infunction) == 0) {
-                printf("OK: Got %s thrown from %s\n", $exceptionname, $infunction);
-            } else {
-                printf("ALMOST: Got %s - but was thrown in %s, not %s (%s)\n", $exceptionname, $function, $infunction, $message);
-            }
-            return $e->getMessage();
-        }
-        printf("OK: Got %s\n", $exceptionname);
-    } else {
-        printf("ALMOST: Got %s (%s) - expected %s\n", get_class($e), $message, $exceptionname);
-    }
-
-    return $e->getMessage();
+    printf("FAILED: Expected %s, but no exception thrown!\n", $expectedException);
+    return '';
 }
 
 function printServer(Server $server)
@@ -649,7 +730,7 @@ function printWriteResult(WriteResult $result, $details = true)
     }
 }
 
-function printWriteConcernError(WriteConcernError $error = null, $details)
+function printWriteConcernError(?WriteConcernError $error = null, $details = null)
 {
     if ($error) {
         /* This stuff is generated by the server, no need for us to test it */
@@ -727,31 +808,23 @@ function failMaxTimeMS(Server $server)
     configureTargetedFailPoint($server, 'maxTimeAlwaysTimeOut', [ 'times' => 1 ]);
 }
 
-function getMOPresetBase() {
-    if (!($BASE = getenv("mongodb_orchestration_base"))) {
-        $BASE = "/phongo/";
-    }
-
-    return $BASE;
-}
-
 function toPHP($var, $typemap = array()) {
-    return MongoDB\BSON\toPHP($var, $typemap);
+    return MongoDB\BSON\Document::fromBSON($var)->toPHP($typemap);
 }
 function fromPHP($var) {
-    return MongoDB\BSON\fromPHP($var);
+    return (string) MongoDB\BSON\Document::fromPHP($var);
 }
 function toJSON($var) {
-    return MongoDB\BSON\toJSON($var);
+    return MongoDB\BSON\Document::fromBSON($var)->toCanonicalExtendedJSON();
 }
 function toCanonicalExtendedJSON($var) {
-    return MongoDB\BSON\toCanonicalExtendedJSON($var);
+    return MongoDB\BSON\Document::fromBSON($var)->toCanonicalExtendedJSON();
 }
 function toRelaxedExtendedJSON($var) {
-    return MongoDB\BSON\toRelaxedExtendedJSON($var);
+    return MongoDB\BSON\Document::fromBSON($var)->toRelaxedExtendedJSON();
 }
 function fromJSON($var) {
-    return MongoDB\BSON\fromJSON($var);
+    return (string) MongoDB\BSON\Document::fromJSON($var);
 }
 
 /* Note: this fail point may terminate the mongod process, so you may want to
@@ -762,11 +835,6 @@ function failGetMore(Manager $manager)
     $primary = $manager->selectServer(new ReadPreference('primary'));
     $version = get_server_version_from_server($primary);
 
-    if (version_compare($version, "3.2", "<")) {
-        configureFailPoint($manager, 'failReceivedGetmore', 'alwaysOn');
-        return;
-    }
-
     if (version_compare($version, "4.0", ">=")) {
         /* We use 237 here, as that's the same original code that MongoD would
          * throw if a cursor had already gone by the time we call getMore. This
